@@ -20,14 +20,17 @@ import java.net.URI;
 import java.net.URISyntaxException;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
+import java.util.EnumMap;
+import java.util.List;
 import java.util.Map;
+import java.util.function.BiFunction;
 
 import javax.jms.Connection;
 import javax.jms.ConnectionFactory;
 import javax.jms.ExceptionListener;
 import javax.jms.JMSContext;
 import javax.jms.JMSException;
-import javax.jms.JMSRuntimeException;
+import javax.jms.MessageListener;
 import javax.jms.QueueConnection;
 import javax.jms.QueueConnectionFactory;
 import javax.jms.TopicConnection;
@@ -50,6 +53,9 @@ import org.apache.qpid.jms.policy.JmsPresettlePolicy;
 import org.apache.qpid.jms.policy.JmsRedeliveryPolicy;
 import org.apache.qpid.jms.provider.Provider;
 import org.apache.qpid.jms.provider.ProviderFactory;
+import org.apache.qpid.jms.tracing.JmsNoOpTracer;
+import org.apache.qpid.jms.tracing.JmsTracer;
+import org.apache.qpid.jms.tracing.JmsTracerFactory;
 import org.apache.qpid.jms.util.IdGenerator;
 import org.apache.qpid.jms.util.PropertyUtil;
 import org.apache.qpid.jms.util.URISupport;
@@ -72,6 +78,8 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
 
     private static String DEFAULT_REMOTE_URI;
 
+    private final EnumMap<JmsConnectionExtensions, BiFunction<Connection, URI, Object>> extensionMap = new EnumMap<>(JmsConnectionExtensions.class);
+
     private URI remoteURI;
     private String username;
     private String password;
@@ -84,9 +92,11 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     private boolean receiveLocalOnly;
     private boolean receiveNoWaitLocalOnly;
     private boolean populateJMSXUserID;
+    private boolean closeLinksThatFailOnReconnect;
     private String queuePrefix = null;
     private String topicPrefix = null;
     private boolean validatePropertyNames = true;
+    private boolean validateSelector = true;
     private boolean awaitClientID = true;
     private boolean useDaemonThread = false;
     private long sendTimeout = JmsConnectionInfo.DEFAULT_SEND_TIMEOUT;
@@ -98,6 +108,8 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     private IdGenerator connectionIdGenerator;
     private String connectionIDPrefix;
     private ExceptionListener exceptionListener;
+    private String tracing;
+    private JmsTracer tracer;
 
     private JmsPrefetchPolicy prefetchPolicy = new JmsDefaultPrefetchPolicy();
     private JmsRedeliveryPolicy redeliveryPolicy = new JmsDefaultRedeliveryPolicy();
@@ -105,8 +117,6 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     private JmsMessageIDPolicy messageIDPolicy = new JmsDefaultMessageIDPolicy();
     private JmsDeserializationPolicy deserializationPolicy = new JmsDefaultDeserializationPolicy();
 
-    private SSLContext sslContext;
-
     public JmsConnectionFactory() {
     }
 
@@ -243,6 +253,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
     }
 
     protected JmsConnectionInfo configureConnectionInfo(String username, String password) throws JMSException {
+        JmsTracer implicitTracer = JmsNoOpTracer.INSTANCE;
         try {
             Map<String, String> properties = PropertyUtil.getProperties(this);
             // Pull out the clientID prop, we need to act differently according to
@@ -264,7 +275,14 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
             connectionInfo.setPresettlePolicy(presettlePolicy.copy());
             connectionInfo.setRedeliveryPolicy(redeliveryPolicy.copy());
             connectionInfo.setDeserializationPolicy(deserializationPolicy.copy());
-            connectionInfo.setSslContextOverride(sslContext);
+            connectionInfo.getExtensionMap().putAll(extensionMap);
+
+            if(tracer != null) {
+                connectionInfo.setTracer(tracer);
+            } else if(tracing != null) {
+                implicitTracer = JmsTracerFactory.create(remoteURI, tracing);
+                connectionInfo.setTracer(implicitTracer);
+            }
 
             // Set properties to make additional configuration changes
             PropertyUtil.setProperties(connectionInfo, properties);
@@ -284,6 +302,10 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
 
             return connectionInfo;
         } catch (Exception e) {
+            try {
+                implicitTracer.close();
+            } catch (Throwable ignored) {}
+
             throw JmsExceptionSupport.create(e);
         }
     }
@@ -307,7 +329,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
 
     @Override
     public JMSContext createContext(String username, String password, int sessionMode) {
-        validateSessionMode(sessionMode);
+        JmsSession.validateSessionMode(sessionMode);
         try {
             JmsConnection connection = (JmsConnection) createConnection(username, password);
             return new JmsContext(connection, sessionMode);
@@ -340,8 +362,8 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
         if (name != null && name.trim().isEmpty() == false) {
             try {
                 return new URI(name);
-            } catch (URISyntaxException e) {
-                throw (IllegalArgumentException) new IllegalArgumentException("Invalid remote URI: " + name).initCause(e);
+            } catch (URISyntaxException ex) {
+                throw new IllegalArgumentException("Invalid remote URI: " + name, ex);
             }
         }
         return null;
@@ -375,28 +397,41 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
      * @param remoteURI
      *        the remoteURI to set
      */
-    public void setRemoteURI(String remoteURI) {
+    public void setRemoteURI(final String remoteURI) {
         if (remoteURI == null || remoteURI.isEmpty()) {
             throw new IllegalArgumentException("Invalid URI: cannot be null or empty");
         }
-        this.remoteURI = createURI(remoteURI);
 
-        if (this.remoteURI.getRawUserInfo() != null) {
+        final URI uri = createURI(remoteURI);
+
+        if (uri.getRawUserInfo() != null) {
             throw new IllegalArgumentException("The supplied URI cannot contain a User-Info section");
         }
 
         try {
-            if (URISupport.isCompositeURI(this.remoteURI)) {
-                CompositeData data = URISupport.parseComposite(this.remoteURI);
+            if (URISupport.isCompositeURI(uri)) {
+                final CompositeData data = URISupport.parseComposite(uri);
+
+                final List<URI> components = data.getComponents();
+                components.forEach(component -> {
+                    if (component.getRawUserInfo() != null) {
+                        throw new IllegalArgumentException("The component server URIs cannot contain a User-Info section");
+                    }
+                });
+
                 applyURIOptions(data.getParameters());
                 this.remoteURI = data.toURI();
-            } else if (this.remoteURI.getRawQuery() != null) {
-                Map<String, String> map = PropertyUtil.parseQuery(this.remoteURI);
+            } else if (uri.getRawQuery() != null) {
+                final Map<String, String> map = PropertyUtil.parseQuery(uri);
                 applyURIOptions(map);
-                this.remoteURI = PropertyUtil.replaceQuery(this.remoteURI, map);
+                this.remoteURI = PropertyUtil.replaceQuery(uri, map);
+            } else {
+                this.remoteURI = uri;
             }
+        } catch (IllegalArgumentException iae) {
+            throw iae;
         } catch (Exception e) {
-            throw new IllegalArgumentException(e.getMessage());
+            throw new IllegalArgumentException(e.getMessage(), e);
         }
     }
 
@@ -413,18 +448,6 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
         }
     }
 
-    private static void validateSessionMode(int mode) {
-        switch (mode) {
-            case JMSContext.AUTO_ACKNOWLEDGE:
-            case JMSContext.CLIENT_ACKNOWLEDGE:
-            case JMSContext.DUPS_OK_ACKNOWLEDGE:
-            case JMSContext.SESSION_TRANSACTED:
-                return;
-            default:
-                throw new JMSRuntimeException("Invalid Session Mode: " + mode);
-        }
-    }
-
     /**
      * @return the user name used for connection authentication.
      */
@@ -535,6 +558,20 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
         this.validatePropertyNames = validatePropertyNames;
     }
 
+    public boolean isValidateSelector() {
+        return validateSelector;
+    }
+
+    /**
+     * Sets whether local validation is performed of a consumers message selector string
+     * conforming to the JMS selector syntax. Default is true.
+     *
+     * @param validateSelector whether to validate consumer message selector strings
+     */
+    public void setValidateSelector(boolean validateSelector) {
+        this.validateSelector = validateSelector;
+    }
+
     /**
      * Gets the currently set close timeout.
      *
@@ -882,7 +919,7 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
      *      the sslContext to use, or null to respect the URI/System property configuration again.
      */
     public void setSslContext(SSLContext sslContext) {
-        this.sslContext = sslContext;
+        this.extensionMap.put(JmsConnectionExtensions.SSL_CONTEXT, (connection, remoteURI) -> sslContext);
     }
 
     public boolean isAwaitClientID() {
@@ -925,6 +962,100 @@ public class JmsConnectionFactory extends JNDIStorable implements ConnectionFact
         this.useDaemonThread = useDaemonThread;
     }
 
+    /**
+     * @return whether links that fail to be created during failover reconnect are closed or not.
+     */
+    public boolean isCloseLinksThatFailOnReconnect() {
+        return closeLinksThatFailOnReconnect;
+    }
+
+    /**
+     * Controls how the client manages errors on recreation of a link (producer / consumer) during
+     * a failover reconnect attempt (defaults to false).
+     * <p>
+     * When false the failure of a link recreation operation while reestablishing a failed connection
+     * results in the client failing that reconnect attempt and retrying the entire connection process
+     * again.  This can be disabled by setting this option to true in which case the client will close
+     * the producer or consumer associated with the failed link create attempt and continue rebuilding
+     * the client resources for the newly reestablished connection.  When failing a consumer link the
+     * client will trigger the {@link ExceptionListener} assigned to the Connection if the link that failed
+     * was a consumer and that consumer had an associated JMS {@link MessageListener}.
+     *
+     * @param closeLinksThatFailOnReconnect
+     * 		whether to close links that fail to establish on failover reconnect.
+     */
+    public void setCloseLinksThatFailOnReconnect(boolean closeLinksThatFailOnReconnect) {
+        this.closeLinksThatFailOnReconnect = closeLinksThatFailOnReconnect;
+    }
+
+    /**
+     * Provides an entry point for extensions to be configured on this {@link ConnectionFactory}.
+     * <p>
+     * If a previous extension with the same name is present it is replaced with the new value or
+     * cleared if the value is null.
+     *
+     * @param extensionName
+     * 		The name of the extension point being added.
+     * @param extension
+     * 		The Function that implements the extension.
+     *
+     * @see JmsConnectionExtensions
+     */
+    public void setExtension(String extensionName, BiFunction<Connection, URI, Object> extension) {
+        JmsConnectionExtensions extensionKey = JmsConnectionExtensions.fromString(extensionName);
+        if (extension == null) {
+            extensionMap.remove(extensionKey);
+        } else {
+            extensionMap.put(extensionKey, extension);
+        }
+    }
+
+    /**
+     * Sets the type name for a tracing provider to use for the connection(s) created using the factory.
+     *
+     * @param tracing
+     *            The tracing provider type name to set
+     */
+    public void setTracing(String tracing) {
+        this.tracing = tracing;
+    }
+
+    public String getTracing() {
+        return tracing;
+    }
+
+    /**
+     * Explicitly sets a tracer instance for use by the connection(s) created from the factory.
+     *
+     * Using this method overrides any implicit creation of a tracer due to use of either URI configuration option
+     * or the {@link JmsConnectionFactory#setTracing(String)} method.
+     *
+     * The provided tracer will have its close method called when a created connection/context is closed,
+     * so if a tracer is to be used across multiple such connections created by this factory then the close
+     * method should handle that appropriately, e.g no-op and have the application and/or underlying tracing
+     * implementation cleanup at shutdown. If no Connection/JMSContext object is returned from a creation
+     * attempt due to an exception being thrown, the tracer provided will not have its close method called
+     * and the application or underlying tracing implementation is responsible for any cleanup required.
+     *
+     * @param tracer
+     *            The tracer to set
+     */
+    public void setTracer(JmsTracer tracer) {
+        this.tracer = tracer;
+    }
+
+    /**
+     * Gets any tracer previously set explicitly on the connection factory using {@link #setTracer(JmsTracer)}.
+     *
+     * Does not return any tracer created implicitly due to use of either URI configuration option
+     * or the {@link JmsConnectionFactory#setTracing(String)} method.
+     *
+     * @return the tracer previously set, or null if none was set.
+     */
+    public JmsTracer getTracer() {
+        return tracer;
+    }
+
     //----- Static Methods ---------------------------------------------------//
 
     /**
