@@ -126,6 +126,7 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
     private final ReentrantLock sendLock = new ReentrantLock();
     private volatile ThreadPoolExecutor deliveryExecutor;
     private volatile ThreadPoolExecutor completionExcecutor;
+    private volatile ProviderFuture asyncSendsCompletion;
     private AtomicReference<Thread> deliveryThread = new AtomicReference<Thread>();
     private boolean deliveryThreadCheckEnabled = true;
     private AtomicReference<Thread> completionThread = new AtomicReference<Thread>();
@@ -351,6 +352,7 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
                     for (JmsMessageProducer producer : new ArrayList<JmsMessageProducer>(this.producers.values())) {
                         producer.shutdown(cause);
                     }
+
                 } catch (JMSException jmsEx) {
                     shutdownError = jmsEx;
                 }
@@ -367,22 +369,6 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
                     }
                 }
 
-                // Ensure that no asynchronous completion sends remain blocked after close.
-                synchronized (sessionInfo) {
-                    if (cause == null) {
-                        cause = new JMSException("Session closed remotely before message transfer result was notified");
-                    }
-
-                    getCompletionExecutor().execute(new FailOrCompleteAsyncCompletionsTask(JmsExceptionSupport.create(cause)));
-                    getCompletionExecutor().shutdown();
-                }
-
-                try {
-                    getCompletionExecutor().awaitTermination(connection.getCloseTimeout(), TimeUnit.MILLISECONDS);
-                } catch (InterruptedException e) {
-                    LOG.trace("Session close awaiting send completions was interrupted");
-                }
-
                 try {
                     if (getSessionMode() == Session.CLIENT_ACKNOWLEDGE) {
                         acknowledge(ACK_TYPE.SESSION_SHUTDOWN);
@@ -391,6 +377,50 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
                     LOG.trace("Exception during session shutdown cleanup acknowledgement", e);
                 }
 
+                // Ensure that no asynchronous completion sends remain blocked after close but wait
+                // using the close timeout for the asynchronous sends to complete normally.
+                final ExecutorService completionExecutor = getCompletionExecutor();
+                try {
+                    synchronized (sessionInfo) {
+                        // Producers are now quiesced and we can await completion of asynchronous sends
+                        // that are still pending a result or timeout once we've done a quick check to
+                        // see if any are actually pending or have completed already.
+                        asyncSendsCompletion = connection.newProviderFuture();
+
+                        if (asyncSendsCompletion != null) {
+                            completionExecutor.execute(() -> {
+                                if (asyncSendQueue.isEmpty()) {
+                                    asyncSendsCompletion.onSuccess();
+                                }
+                            });
+                        }
+                    }
+
+                    try {
+                        if (asyncSendsCompletion != null) {
+                            asyncSendsCompletion.sync(connection.getCloseTimeout(), TimeUnit.MILLISECONDS);
+                        }
+                    } catch (Exception ex) {
+                        LOG.trace("Exception during wait for asynchronous sends to complete", ex);
+                    } finally {
+                        if (cause == null) {
+                            cause = new JMSException("Session closed remotely before message transfer result was notified");
+                        }
+
+                        // as a last task we want to fail any stragglers in the asynchronous send queue and then
+                        // shutdown the queue to prevent any more submissions while the cleanup goes on.
+                        completionExecutor.execute(new FailOrCompleteAsyncCompletionsTask(JmsExceptionSupport.create(cause)));
+                    }
+                } finally {
+                    completionExecutor.shutdown();
+
+                    try {
+                        completionExecutor.awaitTermination(connection.getCloseTimeout(), TimeUnit.MILLISECONDS);
+                    } catch (InterruptedException e) {
+                        LOG.trace("Session close awaiting send completions was interrupted");
+                    }
+                }
+
                 if (shutdownError != null) {
                     throw shutdownError;
                 }
@@ -856,11 +886,12 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
     }
 
     private void send(JmsMessageProducer producer, JmsDestination destination, Message original, int deliveryMode, int priority, long timeToLive, boolean disableMsgId, boolean disableTimestamp, long deliveryDelay, CompletionListener listener) throws JMSException {
+        JmsMessage outbound = null;
         sendLock.lock();
 
-        JmsMessage outbound = null;
-
         try {
+            checkClosed();
+
             original.setJMSDeliveryMode(deliveryMode);
             original.setJMSPriority(priority);
             original.setJMSRedelivered(false);
@@ -909,7 +940,7 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
             }
 
             outbound.getFacade().setDeliveryTime(deliveryTime, hasDelay);
-            if(!isJmsMessage) {
+            if (!isJmsMessage) {
                 // If the original was a foreign message, we still need to update it too.
                 setForeignMessageDeliveryTime(original, deliveryTime);
             }
@@ -977,7 +1008,7 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
             }
         } catch (JMSException jmsEx) {
             // Ensure that on failure case the message is returned to usable state for another send attempt.
-            if(outbound != null) {
+            if (outbound != null) {
                 outbound.onSendComplete();
             }
             throw jmsEx;
@@ -1511,6 +1542,10 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
             if (producerId == null) {
                 asyncSendQueue.clear();
             }
+
+            if (closed.get() && asyncSendsCompletion != null && asyncSendQueue.isEmpty()) {
+                asyncSendsCompletion.onSuccess();
+            }
         }
     }
 
@@ -1577,6 +1612,10 @@ public class JmsSession implements AutoCloseable, Session, QueueSession, TopicSe
                         }
                     }
                 }
+
+                if (closed.get() && asyncSendsCompletion != null && asyncSendQueue.isEmpty()) {
+                    asyncSendsCompletion.onSuccess();
+                }
             } catch (Exception ex) {
                 LOG.error("Async completion task encountered unexpected failure", ex);
             }
