@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -46,6 +46,6 @@ public class JmsTemporaryTopic extends JmsTemporaryDestination implements Tempor
      */
     @Override
     public String getTopicName() {
-        return getName();
+        return getAddress();
     }
 }
