@@ -17,11 +17,11 @@
 package org.apache.qpid.jms.meta;
 
 import org.apache.qpid.jms.JmsDestination;
+import org.apache.qpid.jms.JmsMessageDispatcher;
 import org.apache.qpid.jms.policy.JmsDefaultDeserializationPolicy;
 import org.apache.qpid.jms.policy.JmsDefaultRedeliveryPolicy;
 import org.apache.qpid.jms.policy.JmsDeserializationPolicy;
 import org.apache.qpid.jms.policy.JmsRedeliveryPolicy;
-import org.apache.qpid.jms.util.MessageQueue;
 
 public final class JmsConsumerInfo extends JmsAbstractResource implements Comparable<JmsConsumerInfo> {
 
@@ -41,7 +41,6 @@ public final class JmsConsumerInfo extends JmsAbstractResource implements Compar
     private boolean connectionConsumer;
     private int maxMessages;
     private volatile boolean listener;
-    private final MessageQueue messageQueue;
 
     private JmsRedeliveryPolicy redeliveryPolicy;
     private JmsDeserializationPolicy deserializationPolicy;
@@ -49,16 +48,18 @@ public final class JmsConsumerInfo extends JmsAbstractResource implements Compar
     // Can be used to track the last consumed message.
     private transient long lastDeliveredSequenceId;
 
-    public JmsConsumerInfo(JmsConsumerId consumerId, MessageQueue messageQueue) {
+    private final JmsMessageDispatcher dispatcher;
+
+    public JmsConsumerInfo(JmsConsumerId consumerId, JmsMessageDispatcher dispatcher) {
         if (consumerId == null) {
             throw new IllegalArgumentException("Consumer ID cannot be null");
         }
         this.consumerId = consumerId;
-        this.messageQueue = messageQueue;
+        this.dispatcher = dispatcher;
     }
 
     public JmsConsumerInfo copy() {
-        JmsConsumerInfo info = new JmsConsumerInfo(consumerId, messageQueue);
+        JmsConsumerInfo info = new JmsConsumerInfo(consumerId, dispatcher);
         copy(info);
         return info;
     }
@@ -82,10 +83,6 @@ public final class JmsConsumerInfo extends JmsAbstractResource implements Compar
         info.maxMessages = maxMessages;
     }
 
-    public int getPrefetchedMessageCount() {
-        return messageQueue.size();
-    }
-
     @Override
     public JmsConsumerId getId() {
         return consumerId;
@@ -245,6 +242,10 @@ public final class JmsConsumerInfo extends JmsAbstractResource implements Compar
         this.maxMessages = maxMessages;
     }
 
+    public JmsMessageDispatcher getDispatcher() {
+        return dispatcher;
+    }
+
     @Override
     public String toString() {
         return "JmsConsumerInfo: { " + getId() + ", destination = " + getDestination() + " }";
