@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,17 +16,17 @@
  */
 package org.apache.qpid.jms.provider;
 
-import java.io.IOException;
 import java.net.URI;
-
-import javax.jms.JMSException;
+import java.util.List;
 
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.message.JmsMessageFactory;
 import org.apache.qpid.jms.message.JmsOutboundMessageDispatch;
+import org.apache.qpid.jms.meta.JmsConnectionInfo;
 import org.apache.qpid.jms.meta.JmsConsumerId;
 import org.apache.qpid.jms.meta.JmsResource;
 import org.apache.qpid.jms.meta.JmsSessionId;
+import org.apache.qpid.jms.meta.JmsTransactionInfo;
 import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
 
 /**
@@ -36,6 +36,8 @@ import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
  * This wrapper is meant primarily for Providers that are adding some additional feature
  * on-top of an existing provider such as a discovery based provider that only needs to
  * pass along discovered remote peer information.
+ *
+ * @param <E> the Type of the Provider instance being wrapped.
  */
 public class ProviderWrapper<E extends Provider> implements Provider, ProviderListener {
 
@@ -48,12 +50,12 @@ public class ProviderWrapper<E extends Provider> implements Provider, ProviderLi
     }
 
     @Override
-    public void connect() throws IOException {
-        next.connect();
+    public void connect(JmsConnectionInfo connectionInfo) throws ProviderException {
+        next.connect(connectionInfo);
     }
 
     @Override
-    public void start() throws IOException, IllegalStateException {
+    public void start() throws ProviderException, IllegalStateException {
         if (this.listener == null) {
             throw new IllegalStateException("Cannot start with null ProviderListener");
         }
@@ -71,62 +73,67 @@ public class ProviderWrapper<E extends Provider> implements Provider, ProviderLi
     }
 
     @Override
-    public void create(JmsResource resource, AsyncResult request) throws IOException, JMSException, UnsupportedOperationException {
+    public List<URI> getAlternateURIs() {
+        return next.getAlternateURIs();
+    }
+
+    @Override
+    public void create(JmsResource resource, AsyncResult request) throws ProviderException {
         next.create(resource, request);
     }
 
     @Override
-    public void start(JmsResource resource, AsyncResult request) throws IOException, JMSException {
+    public void start(JmsResource resource, AsyncResult request) throws ProviderException {
         next.start(resource, request);
     }
 
     @Override
-    public void stop(JmsResource resource, AsyncResult request) throws IOException, JMSException {
+    public void stop(JmsResource resource, AsyncResult request) throws ProviderException {
         next.stop(resource, request);
     }
 
     @Override
-    public void destroy(JmsResource resourceId, AsyncResult request) throws IOException, JMSException, UnsupportedOperationException {
+    public void destroy(JmsResource resourceId, AsyncResult request) throws ProviderException {
         next.destroy(resourceId, request);
     }
 
     @Override
-    public void send(JmsOutboundMessageDispatch envelope, AsyncResult request) throws IOException, JMSException {
+    public void send(JmsOutboundMessageDispatch envelope, AsyncResult request) throws ProviderException {
         next.send(envelope, request);
     }
 
     @Override
-    public void acknowledge(JmsSessionId sessionId, AsyncResult request) throws IOException, JMSException {
-        next.acknowledge(sessionId, request);
+    public void acknowledge(JmsSessionId sessionId, ACK_TYPE ackType, AsyncResult request) throws ProviderException {
+        next.acknowledge(sessionId, ackType, request);
     }
 
     @Override
-    public void acknowledge(JmsInboundMessageDispatch envelope, ACK_TYPE ackType, AsyncResult request) throws IOException, JMSException {
+    public void acknowledge(JmsInboundMessageDispatch envelope, ACK_TYPE ackType, AsyncResult request) throws ProviderException {
         next.acknowledge(envelope, ackType, request);
     }
 
     @Override
-    public void commit(JmsSessionId sessionId, AsyncResult request) throws IOException, JMSException, UnsupportedOperationException {
-        next.commit(sessionId, request);
+    public void commit(JmsTransactionInfo transactionInfo, JmsTransactionInfo nextTransactionInfo, AsyncResult request) throws ProviderException {
+        next.commit(transactionInfo, nextTransactionInfo, request);
     }
 
     @Override
-    public void rollback(JmsSessionId sessionId, AsyncResult request) throws IOException, JMSException, UnsupportedOperationException {
-        next.rollback(sessionId, request);
+    public void rollback(JmsTransactionInfo transactionInfo, JmsTransactionInfo nextTransactionInfo, AsyncResult request) throws ProviderException {
+        next.rollback(transactionInfo, nextTransactionInfo, request);
     }
 
     @Override
-    public void recover(JmsSessionId sessionId, AsyncResult request) throws IOException, UnsupportedOperationException {
+    public void recover(JmsSessionId sessionId, AsyncResult request) throws ProviderException {
         next.recover(sessionId, request);
     }
 
     @Override
-    public void unsubscribe(String subscription, AsyncResult request) throws IOException, JMSException, UnsupportedOperationException {
+    public void unsubscribe(String subscription, AsyncResult request) throws ProviderException {
         next.unsubscribe(subscription, request);
     }
 
     @Override
-    public void pull(JmsConsumerId consumerId, long timeout, AsyncResult request) throws IOException, UnsupportedOperationException {
+    public void pull(JmsConsumerId consumerId, long timeout, AsyncResult request) throws ProviderException {
         next.pull(consumerId, timeout, request);
     }
 
@@ -135,6 +142,16 @@ public class ProviderWrapper<E extends Provider> implements Provider, ProviderLi
         return next.getMessageFactory();
     }
 
+    @Override
+    public ProviderFuture newProviderFuture() {
+        return next.newProviderFuture();
+    }
+
+    @Override
+    public ProviderFuture newProviderFuture(ProviderSynchronization synchronization) {
+        return next.newProviderFuture(synchronization);
+    }
+
     @Override
     public void setProviderListener(ProviderListener listener) {
         this.listener = listener;
@@ -150,6 +167,16 @@ public class ProviderWrapper<E extends Provider> implements Provider, ProviderLi
         listener.onInboundMessage(envelope);
     }
 
+    @Override
+    public void onCompletedMessageSend(JmsOutboundMessageDispatch envelope) {
+        listener.onCompletedMessageSend(envelope);
+    }
+
+    @Override
+    public void onFailedMessageSend(JmsOutboundMessageDispatch envelope, ProviderException cause) {
+        listener.onFailedMessageSend(envelope, cause);
+    }
+
     @Override
     public void onConnectionInterrupted(URI remoteURI) {
         listener.onConnectionInterrupted(remoteURI);
@@ -176,13 +203,18 @@ public class ProviderWrapper<E extends Provider> implements Provider, ProviderLi
     }
 
     @Override
-    public void onConnectionFailure(IOException ex) {
+    public void onConnectionFailure(ProviderException ex) {
         listener.onConnectionFailure(ex);
     }
 
     @Override
-    public void onResourceRemotelyClosed(JmsResource resource, Exception cause) {
-        listener.onResourceRemotelyClosed(resource, cause);
+    public void onResourceClosed(JmsResource resource, ProviderException cause) {
+        listener.onResourceClosed(resource, cause);
+    }
+
+    @Override
+    public void onProviderException(ProviderException cause) {
+        listener.onProviderException(cause);
     }
 
     /**
