@@ -55,6 +55,8 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
 
     private static final Logger LOG = LoggerFactory.getLogger(AmqpConsumer.class);
 
+    private static final int INDIVIDUAL_ACKNOWLEDGE = 101;
+
     protected final AmqpSession session;
     protected final int acknowledgementMode;
     protected AsyncResult stopRequest;
@@ -86,7 +88,10 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
     }
 
     private void acknowledgeUndeliveredRecoveredMessages() {
-        if(acknowledgementMode == Session.CLIENT_ACKNOWLEDGE) {
+        if (acknowledgementMode == Session.CLIENT_ACKNOWLEDGE
+                || acknowledgementMode == Session.AUTO_ACKNOWLEDGE
+                    || acknowledgementMode == Session.DUPS_OK_ACKNOWLEDGE
+                        || acknowledgementMode == INDIVIDUAL_ACKNOWLEDGE) {
             // Send dispositions for any messages which were previously delivered and
             // session recovered, but were then not delivered again afterwards.
             Delivery delivery = getEndpoint().head();
@@ -252,7 +257,7 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
             }
 
             JmsInboundMessageDispatch envelope = (JmsInboundMessageDispatch) current.getContext();
-            if(ackType == ACK_TYPE.SESSION_SHUTDOWN && (envelope.isDelivered() || envelope.isRecovered())) {
+            if (ackType == ACK_TYPE.SESSION_SHUTDOWN && (envelope.isDelivered() || envelope.isRecovered())) {
                 handleDisposition(envelope, current, MODIFIED_FAILED);
             } else if (envelope.isDelivered()) {
                 final DeliveryState disposition;
@@ -342,8 +347,7 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
         LOG.debug("Accepted Ack of message: {}", envelope);
         if (!delivery.remotelySettled()) {
             if (session.isTransacted() && !getResourceInfo().isBrowser()) {
-
-                if (session.isTransactionFailed()) {
+                if (session.isTransactionInDoubt()) {
                     LOG.trace("Skipping ack of message {} in failed transaction.", envelope);
                     return;
                 }
@@ -440,9 +444,7 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
                     envelope.getMessage().getFacade().getRedeliveryCount() + 1);
                 envelope.setEnqueueFirst(true);
                 envelope.setDelivered(false);
-                if(acknowledgementMode == Session.CLIENT_ACKNOWLEDGE) {
-                    envelope.setRecovered(true);
-                }
+                envelope.setRecovered(true);
 
                 redispatchList.add(envelope);
             }
@@ -458,6 +460,11 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
         while (reverseIterator.hasPrevious()) {
             deliver(reverseIterator.previous());
         }
+
+        if (deferredClose) {
+            acknowledgeUndeliveredRecoveredMessages();
+            tryCompleteDeferredClose();
+        }
     }
 
     /**
@@ -515,7 +522,7 @@ public class AmqpConsumer extends AmqpAbstractResource<JmsConsumerInfo, Receiver
 
     @Override
     public void processDeliveryUpdates(AmqpProvider provider, Delivery delivery) throws ProviderException {
-        if(delivery.getDefaultDeliveryState() == null){
+        if (delivery.getDefaultDeliveryState() == null){
             delivery.setDefaultDeliveryState(Released.getInstance());
         }
 
