@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,7 +16,9 @@
  */
 package org.apache.qpid.jms.provider.amqp;
 
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ScheduledFuture;
 import java.util.concurrent.TimeUnit;
@@ -30,12 +32,17 @@ import org.apache.qpid.jms.meta.JmsProducerInfo;
 import org.apache.qpid.jms.meta.JmsSessionId;
 import org.apache.qpid.jms.meta.JmsSessionInfo;
 import org.apache.qpid.jms.meta.JmsTransactionId;
+import org.apache.qpid.jms.meta.JmsTransactionInfo;
 import org.apache.qpid.jms.provider.AsyncResult;
+import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
+import org.apache.qpid.jms.provider.ProviderException;
+import org.apache.qpid.jms.provider.amqp.builders.AmqpConsumerBuilder;
+import org.apache.qpid.jms.provider.amqp.builders.AmqpProducerBuilder;
 import org.apache.qpid.proton.engine.Session;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
+public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> implements AmqpResourceParent {
 
     private static final Logger LOG = LoggerFactory.getLogger(AmqpSession.class);
 
@@ -43,56 +50,33 @@ public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
     private final AmqpTransactionContext txContext;
 
     private final Map<JmsConsumerId, AmqpConsumer> consumers = new HashMap<JmsConsumerId, AmqpConsumer>();
+    private final Map<JmsProducerId, AmqpProducer> producers = new HashMap<JmsProducerId, AmqpProducer>();
+
+    public AmqpSession(AmqpConnection connection, JmsSessionInfo info, Session session) {
+        super(info, session, connection);
 
-    public AmqpSession(AmqpConnection connection, JmsSessionInfo info) {
-        super(info, connection.getProtonConnection().session());
         this.connection = connection;
 
-        this.resource.getSessionId().setProviderHint(this);
-        if (this.resource.isTransacted()) {
-            txContext = new AmqpTransactionContext(this);
+        if (info.isTransacted()) {
+            txContext = new AmqpTransactionContext(this, info);
         } else {
             txContext = null;
         }
     }
 
-    @Override
-    public void opened() {
-        if (this.txContext != null) {
-            this.txContext.open(openRequest);
-        } else {
-            super.opened();
-        }
-    }
-
-    @Override
-    protected void doOpen() {
-        long outgoingWindow = getProvider().getSessionOutgoingWindow();
-
-        Session session = this.getEndpoint();
-        session.setIncomingCapacity(Integer.MAX_VALUE);
-        if (outgoingWindow >= 0) {
-            session.setOutgoingWindow(outgoingWindow);
-        }
-
-        this.connection.addSession(this);
-
-        super.doOpen();
-    }
-
-    @Override
-    protected void doClose() {
-        this.connection.removeSession(this);
-        super.doClose();
-    }
-
     /**
      * Perform an acknowledge of all delivered messages for all consumers active in this
      * Session.
+     *
+     * @param ackType
+     *      controls the acknowledgement that is applied to each message.
      */
-    public void acknowledge() {
-        for (AmqpConsumer consumer : consumers.values()) {
-            consumer.acknowledge();
+    public void acknowledge(final ACK_TYPE ackType) {
+        // A consumer whose close was deferred will be closed and removed from the consumers
+        // map so we must copy the entries to safely traverse the collection during this operation.
+        List<AmqpConsumer> consumers = new ArrayList<>(this.consumers.values());
+        for (AmqpConsumer consumer : consumers) {
+            consumer.acknowledge(ackType);
         }
     }
 
@@ -108,60 +92,38 @@ public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
         }
     }
 
-    public AmqpProducer createProducer(JmsProducerInfo producerInfo) {
-        AmqpProducer producer = null;
-
-        if (producerInfo.getDestination() != null || connection.getProperties().isAnonymousRelaySupported()) {
-            LOG.debug("Creating AmqpFixedProducer for: {}", producerInfo.getDestination());
-            producer = new AmqpFixedProducer(this, producerInfo);
-        } else {
-            LOG.debug("Creating an AmqpAnonymousFallbackProducer");
-            producer = new AmqpAnonymousFallbackProducer(this, producerInfo);
-        }
-
-        producer.setPresettle(connection.isPresettleProducers());
-
-        return producer;
+    public void createProducer(JmsProducerInfo producerInfo, AsyncResult request) {
+        AmqpProducerBuilder builder = new AmqpProducerBuilder(this, producerInfo);
+        builder.buildResource(request);
     }
 
     public AmqpProducer getProducer(JmsProducerInfo producerInfo) {
-        return getProducer(producerInfo.getProducerId());
-    }
+        JmsProducerId producerId = producerInfo.getId();
 
-    public AmqpProducer getProducer(JmsProducerId producerId) {
         if (producerId.getProviderHint() instanceof AmqpProducer) {
             return (AmqpProducer) producerId.getProviderHint();
         }
 
-        return null;
+        return producers.get(producerId);
     }
 
-    public AmqpConsumer createConsumer(JmsConsumerInfo consumerInfo) {
-        AmqpConsumer result = null;
-
-        if (consumerInfo.isBrowser()) {
-            result = new AmqpQueueBrowser(this, consumerInfo);
-        } else {
-            result = new AmqpConsumer(this, consumerInfo);
-        }
-
-        result.setPresettle(connection.isPresettleConsumers());
-        return result;
+    public void createConsumer(JmsConsumerInfo consumerInfo, AsyncResult request) {
+        AmqpConsumerBuilder builder = new AmqpConsumerBuilder(this, consumerInfo);
+        builder.buildResource(request);
     }
 
     public AmqpConsumer getConsumer(JmsConsumerInfo consumerInfo) {
-        return getConsumer(consumerInfo.getConsumerId());
-    }
+        JmsConsumerId consumerId = consumerInfo.getId();
 
-    public AmqpConsumer getConsumer(JmsConsumerId consumerId) {
         if (consumerId.getProviderHint() instanceof AmqpConsumer) {
             return (AmqpConsumer) consumerId.getProviderHint();
         }
-        return this.consumers.get(consumerId);
+
+        return consumers.get(consumerId);
     }
 
     public AmqpTransactionContext getTransactionContext() {
-        return this.txContext;
+        return txContext;
     }
 
     /**
@@ -176,7 +138,7 @@ public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
      * @throws Exception if an error occurs while performing the operation.
      */
     public void begin(JmsTransactionId txId, AsyncResult request) throws Exception {
-        if (!this.resource.isTransacted()) {
+        if (!getResourceInfo().isTransacted()) {
             throw new IllegalStateException("Non-transacted Session cannot start a TX.");
         }
 
@@ -186,33 +148,41 @@ public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
     /**
      * Commit the currently running Transaction.
      *
+     * @param transactionInfo
+     *        the JmsTransactionInfo describing the transaction being committed.
+     * @param nextTransactionInfo
+     *        the JmsTransactionInfo describing the transaction that should be started immediately.
      * @param request
      *        The request that will be signaled on completion of this operation.
      *
      * @throws Exception if an error occurs while performing the operation.
      */
-    public void commit(AsyncResult request) throws Exception {
-        if (!this.resource.isTransacted()) {
-            throw new IllegalStateException("Non-transacted Session cannot start a TX.");
+    public void commit(JmsTransactionInfo transactionInfo, JmsTransactionInfo nextTransactionInfo, AsyncResult request) throws Exception {
+        if (!getResourceInfo().isTransacted()) {
+            throw new IllegalStateException("Non-transacted Session cannot commit a TX.");
         }
 
-        getTransactionContext().commit(request);
+        getTransactionContext().commit(transactionInfo, nextTransactionInfo, request);
     }
 
     /**
      * Roll back the currently running Transaction
      *
+     * @param transactionInfo
+     *        the JmsTransactionInfo describing the transaction being rolled back.
+     * @param nextTransactionInfo
+     *        the JmsTransactionInfo describing the transaction that should be started immediately.
      * @param request
      *        The request that will be signaled on completion of this operation.
      *
      * @throws Exception if an error occurs while performing the operation.
      */
-    public void rollback(AsyncResult request) throws Exception {
-        if (!this.resource.isTransacted()) {
-            throw new IllegalStateException("Non-transacted Session cannot start a TX.");
+    public void rollback(JmsTransactionInfo transactionInfo, JmsTransactionInfo nextTransactionInfo, AsyncResult request) throws Exception {
+        if (!getResourceInfo().isTransacted()) {
+            throw new IllegalStateException("Non-transacted Session cannot rollback a TX.");
         }
 
-        getTransactionContext().rollback(request);
+        getTransactionContext().rollback(transactionInfo, nextTransactionInfo, request);
     }
 
     /**
@@ -234,31 +204,45 @@ public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
         return getProvider().getScheduler().schedule(task, delay, TimeUnit.MILLISECONDS);
     }
 
-    void addResource(AmqpConsumer consumer) {
-        consumers.put(consumer.getConsumerId(), consumer);
+    @Override
+    public void addChildResource(AmqpResource resource) {
+        // delegate to the connection if the type is not managed here.
+        if (resource instanceof AmqpConsumer) {
+            AmqpConsumer consumer = (AmqpConsumer) resource;
+            consumers.put(consumer.getConsumerId(), consumer);
+        } else if (resource instanceof AmqpProducer) {
+            AmqpProducer producer = (AmqpProducer) resource;
+            producers.put(producer.getProducerId(), producer);
+        } else {
+            connection.addChildResource(resource);
+        }
     }
 
-    void removeResource(AmqpConsumer consumer) {
-        consumers.remove(consumer.getConsumerId());
+    @Override
+    public void removeChildResource(AmqpResource resource) {
+        // delegate to the connection if the type is not managed here.
+        if (resource instanceof AmqpConsumer) {
+            AmqpConsumer consumer = (AmqpConsumer) resource;
+            consumers.remove(consumer.getConsumerId());
+        } else if (resource instanceof AmqpProducer) {
+            AmqpProducer producer = (AmqpProducer) resource;
+            producers.remove(producer.getProducerId());
+        } else {
+            connection.removeChildResource(resource);
+        }
     }
 
-    /**
-     * Query the Session to see if there are any registered consumer instances that have
-     * a durable subscription with the given subscription name.
-     *
-     * @param subscriptionName
-     *        the name of the subscription being searched for.
-     *
-     * @return true if there is a consumer that has the given subscription.
-     */
-    public boolean containsSubscription(String subscriptionName) {
-        for (AmqpConsumer consumer : consumers.values()) {
-            if (subscriptionName.equals(consumer.getJmsResource().getSubscriptionName())) {
-                return true;
-            }
+    @Override
+    public void handleResourceClosure(AmqpProvider provider, ProviderException error) {
+        List<AmqpConsumer> consumerList = new ArrayList<>(consumers.values());
+        for (AmqpConsumer consumer : consumerList) {
+            consumer.handleResourceClosure(provider, error);
         }
 
-        return false;
+        List<AmqpProducer> producerList = new ArrayList<>(producers.values());
+        for (AmqpProducer producer : producerList) {
+            producer.handleResourceClosure(provider, error);
+        }
     }
 
     /**
@@ -268,32 +252,33 @@ public class AmqpSession extends AmqpAbstractResource<JmsSessionInfo, Session> {
      * @param error
      *        The error to forward on to the Provider error event handler.
      */
-    public void reportError(Exception error) {
+    public void reportError(ProviderException error) {
         getConnection().getProvider().fireProviderException(error);
     }
 
+    @Override
     public AmqpProvider getProvider() {
-        return this.connection.getProvider();
+        return connection.getProvider();
     }
 
     public AmqpConnection getConnection() {
-        return this.connection;
+        return connection;
     }
 
     public JmsSessionId getSessionId() {
-        return this.resource.getSessionId();
-    }
-
-    public Session getProtonSession() {
-        return this.getEndpoint();
+        return getResourceInfo().getId();
     }
 
     boolean isTransacted() {
-        return this.resource.isTransacted();
+        return getResourceInfo().isTransacted();
+    }
+
+    public boolean isTransactionInDoubt() {
+        return txContext == null ? false : txContext.isTransactionInDoubt();
     }
 
     boolean isAsyncAck() {
-        return this.resource.isSendAcksAsync() || isTransacted();
+        return getResourceInfo().isSendAcksAsync() || isTransacted();
     }
 
     @Override
