@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,17 +16,19 @@
  */
 package org.apache.qpid.jms;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.IOException;
 import java.net.URI;
 
+import javax.jms.ConnectionMetaData;
 import javax.jms.ExceptionListener;
 import javax.jms.IllegalStateException;
 import javax.jms.InvalidClientIDException;
@@ -35,13 +37,17 @@ import javax.jms.Session;
 import javax.jms.TemporaryQueue;
 import javax.jms.TemporaryTopic;
 
-import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
+import org.apache.qpid.jms.meta.JmsConnectionId;
+import org.apache.qpid.jms.meta.JmsConnectionInfo;
+import org.apache.qpid.jms.policy.JmsDefaultPrefetchPolicy;
+import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
 import org.apache.qpid.jms.provider.mock.MockProvider;
 import org.apache.qpid.jms.provider.mock.MockProviderFactory;
 import org.apache.qpid.jms.util.IdGenerator;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 
 /**
  * Test basic functionality around JmsConnection
@@ -52,37 +58,45 @@ public class JmsConnectionTest {
 
     private MockProvider provider;
     private JmsConnection connection;
+    private JmsConnectionInfo connectionInfo;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         provider = (MockProvider) MockProviderFactory.create(new URI("mock://localhost"));
+        connectionInfo = new JmsConnectionInfo(new JmsConnectionId("ID:TEST:1"));
+        connectionInfo.setClientId(clientIdGenerator.generateId(), false);
     }
 
-    @After
+    @AfterEach
     public void tearDown() throws Exception {
         if (connection != null) {
             connection.close();
         }
     }
 
-    @Test(timeout=30000, expected=JMSException.class)
+    @Test
+    @Timeout(30)
     public void testJmsConnectionThrowsJMSExceptionProviderStartFails() throws JMSException, IllegalStateException, IOException {
-        provider.getConfiguration().setFailOnStart(true);
-        new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        assertThrows(JMSException.class, () -> {
+            provider.getConfiguration().setFailOnStart(true);
+            try (JmsConnection connection = new JmsConnection(connectionInfo, provider);) {}
+        });
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testStateAfterCreate() throws JMSException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
 
         assertFalse(connection.isStarted());
         assertFalse(connection.isClosed());
         assertFalse(connection.isConnected());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testGetExceptionListener() throws JMSException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
 
         assertNull(connection.getExceptionListener());
         connection.setExceptionListener(new ExceptionListener() {
@@ -95,11 +109,12 @@ public class JmsConnectionTest {
         assertNotNull(connection.getExceptionListener());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testReplacePrefetchPolicy() throws JMSException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
 
-        JmsPrefetchPolicy newPolicy = new JmsPrefetchPolicy();
+        JmsDefaultPrefetchPolicy newPolicy = new JmsDefaultPrefetchPolicy();
         newPolicy.setAll(1);
 
         assertNotSame(newPolicy, connection.getPrefetchPolicy());
@@ -107,55 +122,37 @@ public class JmsConnectionTest {
         assertEquals(newPolicy, connection.getPrefetchPolicy());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testGetConnectionId() throws JMSException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        assertEquals("ID:TEST:1", connection.getConnectionId().toString());
+        connection = new JmsConnection(connectionInfo, provider);
+        assertEquals("ID:TEST:1", connection.getId().toString());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testAddConnectionListener() throws JMSException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        JmsConnectionListener listener = new JmsConnectionListener() {
-
-            @Override
-            public void onInboundMessage(JmsInboundMessageDispatch envelope) {
-            }
-
-            @Override
-            public void onConnectionRestored(URI remoteURI) {
-            }
-
-            @Override
-            public void onConnectionInterrupted(URI remoteURI) {
-            }
-
-            @Override
-            public void onConnectionFailure(Throwable error) {
-            }
-
-            @Override
-            public void onConnectionEstablished(URI remoteURI) {
-            }
-        };
-
+        connection = new JmsConnection(connectionInfo, provider);
+        JmsConnectionListener listener = new JmsDefaultConnectionListener();
         assertFalse(connection.removeConnectionListener(listener));
         connection.addConnectionListener(listener);
         assertTrue(connection.removeConnectionListener(listener));
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testConnectionStart() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
 
         assertFalse(connection.isConnected());
         connection.start();
         assertTrue(connection.isConnected());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testConnectionMulitpleStartCalls() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
 
         assertFalse(connection.isConnected());
         connection.start();
@@ -164,9 +161,10 @@ public class JmsConnectionTest {
         assertTrue(connection.isConnected());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testConnectionStartAndStop() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
 
         assertFalse(connection.isConnected());
         connection.start();
@@ -175,16 +173,20 @@ public class JmsConnectionTest {
         assertTrue(connection.isConnected());
     }
 
-    @Test(timeout=30000, expected=InvalidClientIDException.class)
+    @Test
+    @Timeout(30)
     public void testSetClientIDFromNull() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        assertFalse(connection.isConnected());
-        connection.setClientID("");
+        assertThrows(InvalidClientIDException.class, () -> {
+            connection = new JmsConnection(connectionInfo, provider);
+            assertFalse(connection.isConnected());
+            connection.setClientID("");
+        });
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testCreateNonTXSessionWithTXAckMode() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
         connection.start();
 
         try {
@@ -194,9 +196,10 @@ public class JmsConnectionTest {
         }
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testCreateNonTXSessionWithUnknownAckMode() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
         connection.start();
 
         try {
@@ -206,36 +209,69 @@ public class JmsConnectionTest {
         }
     }
 
-    @Test(timeout=30000, expected=InvalidClientIDException.class)
-    public void testSetClientIDFromEmptyString() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        assertFalse(connection.isConnected());
-        connection.setClientID(null);
-    }
-
-    @Test(timeout=30000, expected=IllegalStateException.class)
-    public void testSetClientIDFailsOnSecondCall() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-
-        assertFalse(connection.isConnected());
-        connection.setClientID("TEST-ID");
-        assertTrue(connection.isConnected());
-        connection.setClientID("TEST-ID");
-    }
-
-    @Test(timeout=30000, expected=IllegalStateException.class)
-    public void testSetClientIDFailsAfterStart() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-
-        assertFalse(connection.isConnected());
+    @Test
+    @Timeout(30)
+    public void testCreateSessionWithUnknownAckMode() throws JMSException, IOException {
+        connection = new JmsConnection(connectionInfo, provider);
         connection.start();
-        assertTrue(connection.isConnected());
-        connection.setClientID("TEST-ID");
+
+        try {
+            connection.createSession(99);
+            fail("Should not allow unkown Ack modes.");
+        } catch (JMSException ex) {
+        }
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
+    public void testCreateSessionDefaultMode() throws JMSException, IOException {
+        connection = new JmsConnection(connectionInfo, provider);
+        connection.start();
+
+        JmsSession session = (JmsSession) connection.createSession();
+        assertEquals(session.getSessionMode(), Session.AUTO_ACKNOWLEDGE);
+    }
+
+    @Test
+    @Timeout(30)
+    public void testSetClientIDFromEmptyString() throws JMSException, IOException {
+        assertThrows(InvalidClientIDException.class, () -> {
+            connection = new JmsConnection(connectionInfo, provider);
+            assertFalse(connection.isConnected());
+            connection.setClientID(null);
+        });
+    }
+
+    @Test
+    @Timeout(30)
+    public void testSetClientIDFailsOnSecondCall() throws JMSException, IOException {
+        assertThrows(IllegalStateException.class, () -> {
+            connection = new JmsConnection(connectionInfo, provider);
+
+            assertFalse(connection.isConnected());
+            connection.setClientID("TEST-ID");
+            assertTrue(connection.isConnected());
+            connection.setClientID("TEST-ID");
+        });
+    }
+
+    @Test
+    @Timeout(30)
+    public void testSetClientIDFailsAfterStart() throws JMSException, IOException {
+        assertThrows(IllegalStateException.class, () -> {
+            connection = new JmsConnection(connectionInfo, provider);
+
+            assertFalse(connection.isConnected());
+            connection.start();
+            assertTrue(connection.isConnected());
+            connection.setClientID("TEST-ID");
+        });
+    }
+
+    @Test
+    @Timeout(30)
     public void testDeleteOfTempQueueOnClosedConnection() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -250,9 +286,10 @@ public class JmsConnectionTest {
         }
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testDeleteOfTempTopicOnClosedConnection() throws JMSException, IOException {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
+        connection = new JmsConnection(connectionInfo, provider);
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
@@ -267,29 +304,38 @@ public class JmsConnectionTest {
         }
     }
 
-    //----- Currently these are unimplemented, these will fail after that ----//
+    @Test
+    @Timeout(30)
+    public void testConnectionCreatedSessionRespectsAcknowledgementMode() throws Exception {
+        connection = new JmsConnection(connectionInfo, provider);
+        connection.start();
 
-    @Test(timeout=30000, expected=JMSException.class)
-    public void testCreateConnectionConsumer() throws Exception {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        connection.createConnectionConsumer((JmsDestination) new JmsTopic(), "", null, 1);
+        JmsSession session = (JmsSession) connection.createSession(Session.SESSION_TRANSACTED);
+        try {
+            session.acknowledge(ACK_TYPE.ACCEPTED);
+            fail("Should be in TX mode and not allow explicit ACK.");
+        } catch (IllegalStateException ise) {
+        }
     }
 
-    @Test(timeout=30000, expected=JMSException.class)
-    public void testCreateConnectionTopicConsumer() throws Exception {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        connection.createConnectionConsumer(new JmsTopic(), "", null, 1);
-    }
+    @Test
+    @Timeout(30)
+    public void testConnectionMetaData() throws Exception {
+        connection = new JmsConnection(connectionInfo, provider);
 
-    @Test(timeout=30000, expected=JMSException.class)
-    public void testCreateConnectionQueueConsumer() throws Exception {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        connection.createConnectionConsumer(new JmsQueue(), "", null, 1);
-    }
+        ConnectionMetaData metaData = connection.getMetaData();
 
-    @Test(timeout=30000, expected=JMSException.class)
-    public void testCreateDurableConnectionConsumer() throws Exception {
-        connection = new JmsConnection("ID:TEST:1", provider, clientIdGenerator);
-        connection.createDurableConnectionConsumer(new JmsTopic(), "id", "", null, 1);
+        assertNotNull(metaData);
+        assertEquals(2, metaData.getJMSMajorVersion());
+        assertEquals(0, metaData.getJMSMinorVersion());
+        assertEquals("2.0", metaData.getJMSVersion());
+        assertNotNull(metaData.getJMSXPropertyNames());
+
+        assertNotNull(metaData.getProviderVersion());
+        assertNotNull(metaData.getJMSProviderName());
+
+        int major = metaData.getProviderMajorVersion();
+        int minor = metaData.getProviderMinorVersion();
+        assertTrue((major + minor) != 0, "Expected non-zero provider major(" + major + ") / minor(" + minor +") version.");
     }
 }
