@@ -21,10 +21,10 @@ package org.apache.qpid.jms.integration;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.SHARED_SUBS;
 import static org.apache.qpid.jms.provider.amqp.AmqpSupport.SUB_NAME_DELIMITER;
 import static org.hamcrest.Matchers.equalTo;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.IOException;
 import java.util.concurrent.CountDownLatch;
@@ -48,12 +48,17 @@ import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
 import org.apache.qpid.jms.test.testpeer.basictypes.AmqpError;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.hamcrest.Matcher;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
 
     private final IntegrationTestFixture testFixture = new IntegrationTestFixture();
 
+    private static final Logger LOG = LoggerFactory.getLogger(SubscriptionsIntegrationTest.class);
+
     // -------------------------------------- //
 
     @Test
@@ -69,7 +74,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCloseSharedDurableTopicSubscriberDetachesWithCloseFalse() throws Exception {
         doSharedTopicSubscriberDetachTestImpl(true);
     }
@@ -79,7 +85,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCloseSharedVolatileTopicSubscriberDetachesWithCloseTrue() throws Exception {
         doSharedTopicSubscriberDetachTestImpl(false);
     }
@@ -133,7 +140,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubscriberLinkNames() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(true, true);
     }
@@ -144,7 +152,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubscriberLinkNamesHaveUniqueCounterSuffix() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(false, true);
     }
@@ -156,7 +165,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubscriberLinkNamesNoClientID() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(true, false);
     }
@@ -168,7 +178,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubscriberLinkNamesHaveUniqueCounterSuffixNoClientID() throws Exception {
         doSharedSubsriberLinkNamesHaveUniqueCounterSuffixTestImpl(false, false);
     }
@@ -258,7 +269,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubsriberLinkNamesMultipleConnectionSubs() throws Exception {
         doMultipleConnectionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(true);
     }
@@ -269,7 +281,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubsriberLinkNamesHaveUniqueCounterSuffixMultipleConnectionSubs() throws Exception {
         doMultipleConnectionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(false);
     }
@@ -348,7 +361,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubsriberLinkNamesMultipleSessionSubs() throws Exception {
         doMultipleSessionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(true);
     }
@@ -359,7 +373,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubsriberLinkNamesHaveUniqueCounterSuffixMultipleSessionSubs() throws Exception {
         doMultipleSessionSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(false);
     }
@@ -429,7 +444,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubsriberLinkNamesMultipleNamedSubs() throws Exception {
         doMultipleNamedSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(true);
     }
@@ -440,7 +456,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubsriberLinkNamesHaveUniqueCounterSuffixMultipleNamedSubs() throws Exception {
         doMultipleNamedSharedSubscriberLinkNamesHaveUniqueCounterSuffixTestImpl(false);
     }
@@ -525,7 +542,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableAndVolatileSubsCoexistUsingDistinctLinkNames() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -572,7 +590,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCreateSharedDurableTopicSubscriberFailsIfNotSupported() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(true, false);
     }
@@ -584,7 +603,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCreateSharedVolatileTopicSubscriberFailsIfNotSupported() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(false, false);
     }
@@ -597,7 +617,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCreateSharedDurableTopicSubscriberFailsIfNotSupportedReleasesLinkName() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(true, true);
     }
@@ -610,7 +631,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCreateSharedVolatileTopicSubscriberFailsIfNotSupportedReleasesLinkName() throws Exception {
         doSharedSubscriptionNotSupportedTestImpl(false, true);
     }
@@ -671,7 +693,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCreateSharedDurableTopicSubscriberSucceedsWithOnlyLinkCapability() throws Exception {
         doSharedSubscriptionLinkCapabilitySupportedTestImpl(true);
     }
@@ -683,7 +706,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testCreateSharedVolatileTopicSubscriberSucceedsWithOnlyLinkCapability() throws Exception {
         doSharedSubscriptionLinkCapabilitySupportedTestImpl(false);
     }
@@ -735,7 +759,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedAndExclusiveDurableSubsCantCoexistSharedFirst() throws Exception {
         doSharedAndExclusiveDurableSubsCantCoexistTestImpl(true);
     }
@@ -746,7 +771,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedAndExclusiveDurableSubsCantCoexistExclusiveFirst() throws Exception {
         doSharedAndExclusiveDurableSubsCantCoexistTestImpl(false);
     }
@@ -805,7 +831,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
 
     // -------------------------------------- //
 
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testExclusiveDurableSubCanOnlyBeActiveOnceAtATime() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Establish connection
@@ -859,7 +886,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testUnsubscribeNonExistingSubscription() throws Exception {
         doUnsubscribeNonExistingSubscriptionTestImpl(true);
     }
@@ -872,7 +900,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testUnsubscribeNonExistingSubscriptionWithoutClientID() throws Exception {
         doUnsubscribeNonExistingSubscriptionTestImpl(false);
     }
@@ -919,7 +948,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testUnsubscribeExclusiveDurableSubWhileActiveThenInactive() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -937,7 +967,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             testPeer.expectLinkFlow();
 
             TopicSubscriber subscriber = session.createDurableSubscriber(dest, subscriptionName);
-            assertNotNull("TopicSubscriber object was null", subscriber);
+            assertNotNull(subscriber, "TopicSubscriber object was null");
 
             // Now try to unsubscribe, should fail
             try {
@@ -973,7 +1003,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testUnsubscribeSharedDurableSubWhileActiveThenInactive() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1058,7 +1089,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testUnsubscribeAfterFailedCreation() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1103,12 +1135,55 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
+    /**
+     * Verifies that an unsubscribe attempt detects when the remote indicates that
+     * the request failed by attaching an error condition to the detach response.
+     *
+     * @throws Exception if an unexpected exception occurs
+     */
+    @Test
+    @Timeout(20)
+    public void testUnsubscribeFailsWhenRemoteDetachResponseIndicatesFailure() throws Exception {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            Connection connection = testFixture.establishConnecton(testPeer);
+            connection.start();
+
+            testPeer.expectBegin();
+            Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+
+            String topicName = "myTopic";
+            String subscriptionName = "mySubscription";
+
+            // Try to unsubscribe, should be able to (strictly speaking an unsub attempt
+            // would probably fail normally, due to no subscription, but this test
+            // doesn't care about that, just that the attempt proceeds, so overlook that.
+            testPeer.expectDurableSubUnsubscribeNullSourceLookup(false, false, subscriptionName, topicName, true);
+            testPeer.expectDetach(true, true, true, AmqpError.RESOURCE_LOCKED,
+                    "Cannot unsubscibe when there are active consumers");
+
+            try {
+                session.unsubscribe(subscriptionName);
+                fail("Should throw an error if the remote indicate detach failed");
+            } catch (JMSException jmsEx) {
+                LOG.info("Caught expected exception on unsubscribe: {}", jmsEx.getMessage());
+            }
+
+            testPeer.waitForAllHandlersToComplete(1000);
+
+            testPeer.expectClose();
+            connection.close();
+
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
+
     /**
      * Verifies that subscriber cleanup occurs when the subscriber is remotely closed (after creation).
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testRemotelyDetachLinkWithDurableSharedConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1157,7 +1232,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             MessageConsumer subscriber2 = session2.createSharedDurableConsumer(dest,  subscriptionName);
             assertNotNull(subscriber2);
 
-            assertTrue("Consumer closed callback didn't trigger", subscriberClosed.await(5, TimeUnit.SECONDS));
+            assertTrue(subscriberClosed.await(5, TimeUnit.SECONDS), "Consumer closed callback didn't trigger");
 
             testPeer.waitForAllHandlersToComplete(1000);
 
@@ -1196,7 +1271,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubChangeOfTopic() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(true, true, false);
     }
@@ -1208,7 +1284,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubChangeOfTopic() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(false, true, false);
     }
@@ -1220,7 +1297,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubChangeOfSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(true, false, true);
     }
@@ -1232,7 +1310,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubChangeOfSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(false, false, true);
     }
@@ -1244,7 +1323,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedDurableSubChangeOfTopicAndSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(true, true, true);
     }
@@ -1256,7 +1336,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected exception occurs
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedVolatileSubChangeOfTopicAndSelector() throws Exception {
         doSharedSubChangeOfDetailsTestImpl(false, true, true);
     }
@@ -1362,7 +1443,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testRemotelyEndSessionWithDurableSharedConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1411,7 +1493,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             MessageConsumer subscriber2 = session2.createSharedDurableConsumer(dest,  subscriptionName);
             assertNotNull(subscriber2);
 
-            assertTrue("Session closed callback didn't trigger", sessionClosed.await(5, TimeUnit.SECONDS));
+            assertTrue(sessionClosed.await(5, TimeUnit.SECONDS), "Session closed callback didn't trigger");
 
             testPeer.waitForAllHandlersToComplete(1000);
 
@@ -1446,7 +1528,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testLocallyEndSessionWithSharedConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1530,7 +1613,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSubscriptionNameNotAllowedToHaveNameSeparator() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             // Add server connection capability to indicate support for shared-subs
@@ -1595,7 +1679,8 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
 
     // -------------------------------------- //
 
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testSharedTopicSubscriberBehavesLikeNoClientIDWasSetWhenAwaitClientIdOptionIsFalse() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             int serverPort = testPeer.getServerPort();
@@ -1604,7 +1689,7 @@ public class SubscriptionsIntegrationTest extends QpidJmsTestCase {
             Symbol[] serverCapabilities = new Symbol[]{SHARED_SUBS};
 
             testPeer.expectSaslAnonymous();
-            testPeer.expectOpen(new Symbol[] { AmqpSupport.SOLE_CONNECTION_CAPABILITY }, serverCapabilities, null);
+            testPeer.expectOpen(null, serverCapabilities);
             testPeer.expectBegin();
 
             ConnectionFactory factory = new JmsConnectionFactory("amqp://localhost:" + serverPort + "?jms.awaitClientID=false");
