@@ -18,22 +18,24 @@
  */
 package org.apache.qpid.jms.integration;
 
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.arrayContaining;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.greaterThan;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.Matchers.nullValue;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.IOException;
 import java.util.ArrayDeque;
 import java.util.Deque;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicReference;
 
 import javax.jms.Connection;
 import javax.jms.JMSException;
@@ -48,10 +50,12 @@ import javax.jms.TransactionRolledBackException;
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsDefaultConnectionListener;
 import org.apache.qpid.jms.JmsOperationTimedOutException;
+import org.apache.qpid.jms.exceptions.JmsConnectionFailedException;
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.policy.JmsDefaultPrefetchPolicy;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
+import org.apache.qpid.jms.test.testpeer.basictypes.AmqpError;
 import org.apache.qpid.jms.test.testpeer.describedtypes.Accepted;
 import org.apache.qpid.jms.test.testpeer.describedtypes.Declare;
 import org.apache.qpid.jms.test.testpeer.describedtypes.Declared;
@@ -62,6 +66,7 @@ import org.apache.qpid.jms.test.testpeer.describedtypes.Released;
 import org.apache.qpid.jms.test.testpeer.describedtypes.TransactionalState;
 import org.apache.qpid.jms.test.testpeer.describedtypes.sections.AmqpValueDescribedType;
 import org.apache.qpid.jms.test.testpeer.matchers.AcceptedMatcher;
+import org.apache.qpid.jms.test.testpeer.matchers.ErrorMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.ModifiedMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.ReleasedMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.SourceMatcher;
@@ -70,28 +75,26 @@ import org.apache.qpid.jms.test.testpeer.matchers.sections.MessageAnnotationsSec
 import org.apache.qpid.jms.test.testpeer.matchers.sections.MessageHeaderSectionMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.sections.TransferPayloadCompositeMatcher;
 import org.apache.qpid.jms.test.testpeer.matchers.types.EncodedAmqpValueMatcher;
-import org.apache.qpid.jms.util.QpidJMSTestRunner;
-import org.apache.qpid.jms.util.Repeat;
 import org.apache.qpid.proton.amqp.Binary;
 import org.apache.qpid.proton.amqp.DescribedType;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.UnsignedInteger;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
  * Tests for behavior of Transacted Session operations.
  */
-@RunWith(QpidJMSTestRunner.class)
 public class TransactionsIntegrationTest extends QpidJmsTestCase {
 
     private static final Logger LOG = LoggerFactory.getLogger(TransactionsIntegrationTest.class);
 
     private final IntegrationTestFixture testFixture = new IntegrationTestFixture();
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testTransactionRolledBackOnSessionClose() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -118,7 +121,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testTransactionCommitFailWithEmptyRejectedDisposition() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -154,7 +158,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId1);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
 
             producer.send(session.createMessage());
 
@@ -182,7 +186,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testProducedMessagesAfterCommitOfSentMessagesFails() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -218,7 +223,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId1);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
 
             producer.send(session.createMessage());
 
@@ -249,7 +254,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId2);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
             testPeer.expectDischarge(txnId2, true);
 
             producer.send(session.createMessage());
@@ -261,7 +266,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testProducedMessagesAfterRollbackSentMessagesFails() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -298,7 +304,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId1);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
 
             producer.send(session.createMessage());
 
@@ -328,7 +334,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId2);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
             testPeer.expectDischarge(txnId2, true);
 
             producer.send(session.createMessage());
@@ -340,32 +346,38 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCommitTransactedSessionWithConsumerReceivingAllMessages() throws Exception {
         doCommitTransactedSessionWithConsumerTestImpl(1, 1, false, false);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCommitTransactedSessionWithConsumerReceivingAllMessagesAndCloseBefore() throws Exception {
         doCommitTransactedSessionWithConsumerTestImpl(1, 1, true, true);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCommitTransactedSessionWithConsumerReceivingAllMessagesAndCloseAfter() throws Exception {
         doCommitTransactedSessionWithConsumerTestImpl(1, 1, true, false);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCommitTransactedSessionWithConsumerReceivingSomeMessages() throws Exception {
         doCommitTransactedSessionWithConsumerTestImpl(5, 2, false, false);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCommitTransactedSessionWithConsumerReceivingSomeMessagesAndClosesBefore() throws Exception {
         doCommitTransactedSessionWithConsumerTestImpl(5, 2, true, true);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCommitTransactedSessionWithConsumerReceivingSomeMessagesAndClosesAfter() throws Exception {
         doCommitTransactedSessionWithConsumerTestImpl(5, 2, true, false);
     }
@@ -419,7 +431,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             }
 
             // Ensure all the messages arrived so that the matching below is deterministic
-            assertTrue("Expected transfers didnt occur: " + expected.getCount(), expected.await(10, TimeUnit.SECONDS));
+            assertTrue(expected.await(10, TimeUnit.SECONDS), "Expected transfers didnt occur: " + expected.getCount());
 
             // Expect the consumer to close now
             if (closeConsumer && closeBeforeCommit) {
@@ -480,7 +492,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testConsumerWithNoMessageCanCloseBeforeCommit() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -527,7 +540,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testConsumerWithNoMessageCanCloseBeforeRollback() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -574,7 +588,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testProducedMessagesOnTransactedSessionCarryTxnId() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -610,7 +625,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
             testPeer.expectDischarge(txnId, true);
 
             producer.send(session.createMessage());
@@ -622,7 +637,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testProducedMessagesOnTransactedSessionCanBeReused() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -662,7 +678,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
                 txState.setTxnId(txnId);
                 txState.setOutcome(new Accepted());
 
-                testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+                testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
 
                 message.setIntProperty("sequence", i);
 
@@ -679,22 +695,26 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackTransactedSessionWithConsumerReceivingAllMessages() throws Exception {
         doRollbackTransactedSessionWithConsumerTestImpl(1, 1, false);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackTransactedSessionWithConsumerReceivingAllMessagesThenCloses() throws Exception {
         doRollbackTransactedSessionWithConsumerTestImpl(1, 1, true);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackTransactedSessionWithConsumerReceivingSomeMessages() throws Exception {
         doRollbackTransactedSessionWithConsumerTestImpl(5, 2, false);
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackTransactedSessionWithConsumerReceivingSomeMessagesThenCloses() throws Exception {
         doRollbackTransactedSessionWithConsumerTestImpl(5, 2, true);
     }
@@ -791,7 +811,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackTransactedSessionWithPrefetchFullBeforeStoppingConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             final int messageCount = 5;
@@ -831,7 +852,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
 
             producer.send(session.createMessage());
 
@@ -857,7 +878,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackTransactedSessionWithPrefetchFullyUtilisedByDrainWhenStoppingConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             final int messageCount = 5;
@@ -898,7 +920,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             txState.setTxnId(txnId);
             txState.setOutcome(new Accepted());
 
-            testPeer.expectTransfer(messageMatcher, stateMatcher, false, txState, true);
+            testPeer.expectTransfer(messageMatcher, stateMatcher, txState, true);
 
             producer.send(session.createMessage());
 
@@ -928,7 +950,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testDefaultOutcomeIsModifiedForConsumerSourceOnTransactedSession() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -965,7 +988,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testCoordinatorLinkSupportedOutcomes() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -996,7 +1020,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackErrorCoordinatorClosedOnCommit() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1030,7 +1055,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testRollbackErrorWhenCoordinatorRemotelyClosed() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1066,7 +1092,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testJMSErrorCoordinatorClosedOnRollback() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1100,7 +1127,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testJMSExceptionOnRollbackWhenCoordinatorRemotelyClosed() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1136,7 +1164,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testSendAfterCoordinatorLinkClosedDuringTX() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1186,7 +1215,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testReceiveAfterCoordinatorLinkClosedDuringTX() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1241,7 +1271,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testSessionCreateFailsOnDeclareTimeout() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
@@ -1251,6 +1282,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             testPeer.expectBegin();
             testPeer.expectCoordinatorAttach();
             testPeer.expectDeclareButDoNotRespond();
+            // Expect the AMQP session to be closed due to the JMS session creation failure.
+            testPeer.expectEnd();
 
             try {
                 connection.createSession(true, Session.SESSION_TRANSACTED);
@@ -1268,7 +1301,70 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
+    public void testSessionCreateFailsOnDeclareRejection() throws Exception {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            Connection connection = testFixture.establishConnecton(testPeer);
+            connection.start();
+
+            testPeer.expectBegin();
+            testPeer.expectCoordinatorAttach();
+
+            // First expect an unsettled 'declare' transfer to the txn coordinator, and
+            // reply with a Rejected disposition state to indicate failure.
+            testPeer.expectDeclareAndReject();
+            // Expect the AMQP session to be closed due to the JMS session creation failure.
+            testPeer.expectEnd();
+
+            try {
+                connection.createSession(true, Session.SESSION_TRANSACTED);
+                fail("should have thrown");
+            } catch (JMSException jmse) {
+                // Expected
+            }
+
+            testPeer.expectClose();
+            connection.close();
+
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
+
+    @Test
+    @Timeout(20)
+    public void testSessionCreateFailsOnCoordinatorLinkRefusal() throws Exception {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            Connection connection = testFixture.establishConnecton(testPeer);
+            connection.start();
+
+            testPeer.expectBegin();
+
+            // Expect coordinator link, refuse it, expect detach reply
+            String errorMessage = "CoordinatorLinkRefusal-breadcrumb";
+            testPeer.expectCoordinatorAttach(true, false, AmqpError.NOT_IMPLEMENTED, errorMessage);
+            testPeer.expectDetach(true, false, false);
+
+            // Expect the AMQP session to be closed due to the JMS session creation failure.
+            testPeer.expectEnd();
+
+            try {
+                connection.createSession(true, Session.SESSION_TRANSACTED);
+                fail("should have thrown");
+            } catch (JMSException jmse) {
+                assertNotNull(jmse.getMessage());
+                assertTrue(jmse.getMessage().contains(errorMessage), "Expected exception message to contain breadcrumb");
+            }
+
+            testPeer.expectClose();
+            connection.close();
+
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
+
+    @Test
+    @Timeout(20)
     public void testTransactionRolledBackOnSessionCloseTimesOut() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
@@ -1302,7 +1398,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testTransactionRolledBackTimesOut() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
@@ -1343,7 +1440,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testTransactionCommitTimesOut() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
@@ -1384,7 +1482,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=20000)
+    @Test
+    @Timeout(20)
     public void testTransactionCommitTimesOutAndNoNextBeginTimesOut() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JmsConnection connection = (JmsConnection) testFixture.establishConnecton(testPeer);
@@ -1427,7 +1526,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout = 20000)
+    @Test
+    @Timeout(20)
     public void testRollbackWithNoResponseForSuspendConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer, "?amqp.drainTimeout=1000");
@@ -1486,8 +1586,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=30000)
-    @Repeat(repetitions = 1)
+    @Test
+    @Timeout(30)
     public void testConsumerMessageOrderOnTransactedSession() throws IOException, Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1503,7 +1603,7 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             Binary txnId = new Binary(new byte[]{ (byte) 1, (byte) 2, (byte) 3, (byte) 4});
             TransferPayloadCompositeMatcher declareMatcher = new TransferPayloadCompositeMatcher();
             declareMatcher.setMessageContentMatcher(new EncodedAmqpValueMatcher(new Declare()));
-            testPeer.expectTransfer(declareMatcher, nullValue(), false, new Declared().setTxnId(txnId), true);
+            testPeer.expectTransfer(declareMatcher, nullValue(), new Declared().setTxnId(txnId), true);
 
             Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
             Queue queue = session.createQueue("myQueue");
@@ -1547,7 +1647,8 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test(timeout=60000)
+    @Test
+    @Timeout(60)
     public void testConsumeManyWithSingleTXPerMessage() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             Connection connection = testFixture.establishConnecton(testPeer);
@@ -1620,4 +1721,110 @@ public class TransactionsIntegrationTest extends QpidJmsTestCase {
             testPeer.waitForAllHandlersToComplete(3000);
         }
     }
+
+    @Test
+    @Timeout(20)
+    public void testTransactionDeclaredDispositionWithoutTxnId() throws Exception {
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            Connection connection = testFixture.establishConnecton(testPeer);
+            connection.start();
+
+            AtomicReference<JMSException> failure = new AtomicReference<>();
+            CountDownLatch exceptionListenerFired = new CountDownLatch(1);
+            connection.setExceptionListener(jmse -> {
+                failure.compareAndSet(null, jmse);
+                exceptionListenerFired.countDown();
+            });
+
+            testPeer.expectBegin();
+            testPeer.expectCoordinatorAttach();
+
+            // Expect declare, reply declared but without a txn-id, which is illegal.
+            testPeer.expectDeclare(null);
+
+            ErrorMatcher errorMatcher = new ErrorMatcher()
+                    .withCondition(equalTo(AmqpError.DECODE_ERROR))
+                    .withDescription(equalTo("The txn-id field cannot be omitted"));
+            testPeer.expectClose(errorMatcher, false);
+            testPeer.setSuppressReadExceptionOnClose(true);
+
+            try {
+                connection.createSession(true, Session.SESSION_TRANSACTED);
+                fail("expected exception to be thrown");
+            } catch (JMSException e) {
+                // Expected
+            }
+
+            assertTrue(exceptionListenerFired.await(3, TimeUnit.SECONDS), "The ExceptionListener should have been alerted");
+            JMSException ex = failure.get();
+            assertTrue(ex instanceof JmsConnectionFailedException, "Unexpected exception type: " + ex);
+
+            assertThat("Unexpected exception type: ", ex.getMessage(),
+                    equalTo("The JMS connection has failed: Error in proton Transport: The txn-id field cannot be omitted [condition = amqp:decode-error]"));
+
+            testPeer.waitForAllHandlersToComplete(1000);
+
+            connection.close(); // Already nuked under the covers due to txn-id being missing
+        }
+    }
+
+    @Test
+    @Timeout(30)
+    public void testAsyncConsumerAcksAfterCommitAndBeginWhenCommitCalledInOnMessage() throws Exception {
+        final Binary txnId = new Binary(new byte[]{ (byte) 5, (byte) 6, (byte) 7, (byte) 8});
+
+        final TransferPayloadCompositeMatcher messageMatcher = new TransferPayloadCompositeMatcher();
+        messageMatcher.setHeadersMatcher(new MessageHeaderSectionMatcher(true));
+        messageMatcher.setMessageAnnotationsMatcher(new MessageAnnotationsSectionMatcher(true));
+
+        final TransactionalStateMatcher transferStateMatcher = new TransactionalStateMatcher();
+        transferStateMatcher.withTxnId(equalTo(txnId));
+        transferStateMatcher.withOutcome(nullValue());
+
+        final TransactionalStateMatcher dispositionStateMatcher = new TransactionalStateMatcher();
+        dispositionStateMatcher.withTxnId(equalTo(txnId));
+        dispositionStateMatcher.withOutcome(new AcceptedMatcher());
+
+        final TransactionalState transferTxnOutcome = new TransactionalState();
+        transferTxnOutcome.setTxnId(txnId);
+        transferTxnOutcome.setOutcome(new Accepted());
+
+        try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
+            Connection connection = testFixture.establishConnecton(testPeer, "?amqp.drainTimeout=1000");
+            connection.start();
+
+            testPeer.expectBegin();
+            testPeer.expectCoordinatorAttach();
+            testPeer.expectDeclare(txnId);
+            testPeer.expectReceiverAttach();
+            testPeer.expectLinkFlowRespondWithTransfer(null, null, null, null, new AmqpValueDescribedType("content"), 1);
+            testPeer.expectDisposition(true, dispositionStateMatcher);
+            testPeer.expectSenderAttach();
+            testPeer.expectTransfer(messageMatcher, transferStateMatcher, transferTxnOutcome, true);
+            testPeer.expectDischarge(txnId, false);
+            testPeer.expectDeclare(txnId);
+
+            // Test that consumer onMessage delivery and a send within the listener are
+            // both included into the same transaction prior to the commit in the listener.
+            Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
+            Queue queue = session.createQueue("myQueue");
+            MessageConsumer messageConsumer = session.createConsumer(queue);
+            messageConsumer.setMessageListener((message) -> {
+                try {
+                    session.createProducer(queue).send(session.createTextMessage("sample"));
+                    session.commit();
+                } catch (JMSException jmsEx) {
+                    throw new RuntimeException("Behaving badly since commit already did", jmsEx);
+                }
+            });
+
+            testPeer.waitForAllHandlersToComplete(1000);
+
+            testPeer.expectDischarge(txnId, true);
+            testPeer.expectClose();
+            connection.close();
+
+            testPeer.waitForAllHandlersToComplete(1000);
+        }
+    }
 }
