@@ -16,16 +16,21 @@
  */
 package org.apache.qpid.jms.message;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.EOFException;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.lang.reflect.Array;
 import java.util.Arrays;
+import java.util.List;
+import java.util.Map;
 
 import javax.jms.BytesMessage;
 import javax.jms.JMSException;
@@ -37,7 +42,7 @@ import javax.jms.MessageNotWriteableException;
 import org.apache.qpid.jms.message.facade.JmsBytesMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestBytesMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFactory;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 
 /**
@@ -67,7 +72,7 @@ public class JmsBytesMessageTest {
         JmsBytesMessage bytesMessage = factory.createBytesMessage();
         bytesMessage.writeBytes(bytes);
         bytesMessage.reset();
-        assertEquals("Message reports unexpected length", bytes.length, bytesMessage.getBodyLength());
+        assertEquals(bytes.length, bytesMessage.getBodyLength(), "Message reports unexpected length");
     }
 
     /**
@@ -76,10 +81,12 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected = MessageNotReadableException.class)
+    @Test
     public void testGetBodyLengthOnNewMessageThrowsMessageNotReadableException() throws Exception {
-        JmsBytesMessage bytesMessage = factory.createBytesMessage();
-        bytesMessage.getBodyLength();
+        assertThrows(MessageNotReadableException.class, () -> {
+            JmsBytesMessage bytesMessage = factory.createBytesMessage();
+            bytesMessage.getBodyLength();
+        });
     }
 
     @Test
@@ -87,7 +94,7 @@ public class JmsBytesMessageTest {
         JmsBytesMessage bytesMessage = factory.createBytesMessage();
         bytesMessage.onDispatch();
         //verify attempting to read bytes returns -1, i.e EOS
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, bytesMessage.readBytes(new byte[1]));
+        assertEquals(END_OF_STREAM, bytesMessage.readBytes(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
@@ -104,10 +111,9 @@ public class JmsBytesMessageTest {
         assertTrue(Arrays.equals(content, receivedBytes));
 
         // verify no more bytes remain, i.e EOS
-        assertEquals("Expected input stream to be at end but data was returned",
-                     END_OF_STREAM, bytesMessage.readBytes(new byte[1]));
+        assertEquals(END_OF_STREAM, bytesMessage.readBytes(new byte[1]), "Expected input stream to be at end but data was returned");
 
-        assertEquals("Message reports unexpected length", content.length, bytesMessage.getBodyLength());
+        assertEquals(content.length, bytesMessage.getBodyLength(), "Message reports unexpected length");
     }
 
     /**
@@ -116,14 +122,16 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected = MessageNotWriteableException.class)
+    @Test
     public void testReceivedBytesMessageThrowsMessageNotWriteableExceptionOnWriteBytes() throws Exception {
-        byte[] content = "myBytesData".getBytes();
-        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
+        assertThrows(MessageNotWriteableException.class, () -> {
+            byte[] content = "myBytesData".getBytes();
+            JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
-        JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
-        bytesMessage.onDispatch();
-        bytesMessage.writeBytes(content);
+            JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
+            bytesMessage.onDispatch();
+            bytesMessage.writeBytes(content);
+        });
     }
 
     /**
@@ -132,11 +140,13 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected = MessageNotReadableException.class)
+    @Test
     public void testNewBytesMessageThrowsMessageNotReadableOnReadBytes() throws Exception {
-        JmsBytesMessage bytesMessage = factory.createBytesMessage();
-        byte[] receivedBytes = new byte[1];
-        bytesMessage.readBytes(receivedBytes);
+        assertThrows(MessageNotReadableException.class, () -> {
+            JmsBytesMessage bytesMessage = factory.createBytesMessage();
+            byte[] receivedBytes = new byte[1];
+            bytesMessage.readBytes(receivedBytes);
+        });
     }
 
     /**
@@ -152,9 +162,9 @@ public class JmsBytesMessageTest {
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
-        assertTrue("Message should not be writable", bytesMessage.isReadOnlyBody());
+        assertTrue(bytesMessage.isReadOnlyBody(), "Message should not be writable");
         bytesMessage.clearBody();
-        assertFalse("Message should be writable", bytesMessage.isReadOnlyBody());
+        assertFalse(bytesMessage.isReadOnlyBody(), "Message should be writable");
     }
 
     /**
@@ -171,11 +181,11 @@ public class JmsBytesMessageTest {
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
 
-        assertTrue("Expected message content but none was present", facade.getBodyLength() > 0);
-        assertEquals("Expected data from facade", 1, facade.getInputStream().read(new byte[1]));
+        assertTrue(facade.getBodyLength() > 0, "Expected message content but none was present");
+        assertEquals(1, facade.getInputStream().read(new byte[1]), "Expected data from facade");
         bytesMessage.clearBody();
-        assertTrue("Expected no message content from facade", facade.getBodyLength() == 0);
-        assertEquals("Expected no data from facade, but got some", END_OF_STREAM, facade.getInputStream().read(new byte[1]));
+        assertTrue(facade.getBodyLength() == 0, "Expected no message content from facade");
+        assertEquals(END_OF_STREAM, facade.getInputStream().read(new byte[1]), "Expected no data from facade, but got some");
     }
 
     /**
@@ -191,7 +201,7 @@ public class JmsBytesMessageTest {
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
-        assertEquals("Unexpected message length", content.length, bytesMessage.getBodyLength());
+        assertEquals(content.length, bytesMessage.getBodyLength(), "Unexpected message length");
         bytesMessage.clearBody();
 
         try {
@@ -243,10 +253,10 @@ public class JmsBytesMessageTest {
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
 
-        assertFalse("Message should be writable", bytesMessage.isReadOnlyBody());
+        assertFalse(bytesMessage.isReadOnlyBody(), "Message should be writable");
         bytesMessage.writeBytes(content);
         bytesMessage.reset();
-        assertTrue("Message should not be writable", bytesMessage.isReadOnlyBody());
+        assertTrue(bytesMessage.isReadOnlyBody(), "Message should not be writable");
 
         // retrieve the bytes, check they match
         byte[] resetBytes = new byte[content.length];
@@ -264,7 +274,7 @@ public class JmsBytesMessageTest {
     public void testReadBytesWithZeroLengthDestination() throws Exception {
         JmsBytesMessage bytesMessage = factory.createBytesMessage();
         bytesMessage.reset();
-        assertEquals("Did not expect any bytes to be read", 0, bytesMessage.readBytes(new byte[0]));
+        assertEquals(0, bytesMessage.readBytes(new byte[0]), "Did not expect any bytes to be read");
     }
 
     /**
@@ -273,12 +283,14 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected=IndexOutOfBoundsException.class)
+    @Test
     public void testReadBytesWithNegativeLengthThrowsIOOBE() throws Exception
     {
-        JmsBytesMessage bytesMessage = factory.createBytesMessage();
-        bytesMessage.reset();
-        bytesMessage.readBytes(new byte[0], -1);
+        assertThrows(IndexOutOfBoundsException.class, () -> {
+            JmsBytesMessage bytesMessage = factory.createBytesMessage();
+            bytesMessage.reset();
+            bytesMessage.readBytes(new byte[0], -1);
+        });
     }
 
     /**
@@ -288,11 +300,13 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected=IndexOutOfBoundsException.class)
+    @Test
     public void testReadBytesWithLengthGreatThanArraySizeThrowsIOOBE() throws Exception {
-        JmsBytesMessage bytesMessage = factory.createBytesMessage();
-        bytesMessage.reset();
-        bytesMessage.readBytes(new byte[1], 2);
+        assertThrows(IndexOutOfBoundsException.class, () -> {
+            JmsBytesMessage bytesMessage = factory.createBytesMessage();
+            bytesMessage.reset();
+            bytesMessage.readBytes(new byte[1], 2);
+        });
     }
 
     /**
@@ -301,10 +315,12 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected=NullPointerException.class)
+    @Test
     public void testWriteObjectWithNullThrowsNPE() throws Exception {
-        JmsBytesMessage bytesMessage = factory.createBytesMessage();
-        bytesMessage.writeObject(null);
+        assertThrows(NullPointerException.class, () -> {
+            JmsBytesMessage bytesMessage = factory.createBytesMessage();
+            bytesMessage.writeObject(null);
+        });
     }
 
     /**
@@ -313,10 +329,12 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test(expected=MessageFormatException.class)
+    @Test
     public void testWriteObjectWithIllegalTypeThrowsMFE() throws Exception {
-        JmsBytesMessage bytesMessage = factory.createBytesMessage();
-        bytesMessage.writeObject(new Object());
+        assertThrows(MessageFormatException.class, () -> {
+            JmsBytesMessage bytesMessage = factory.createBytesMessage();
+            bytesMessage.writeObject(new Object());
+        });
     }
 
     @Test
@@ -447,8 +465,8 @@ public class JmsBytesMessageTest {
             msg.writeObject(Short.valueOf((short) 3));
             msg.writeObject(Integer.valueOf(3));
             msg.writeObject(Long.valueOf(300L));
-            msg.writeObject(new Float(3.3f));
-            msg.writeObject(new Double(3.3));
+            msg.writeObject(Float.valueOf(3.3f));
+            msg.writeObject(Double.valueOf(3.3));
             msg.writeObject(new byte[3]);
         } catch (MessageFormatException mfe) {
             fail("objectified primitives should be allowed");
@@ -974,6 +992,44 @@ public class JmsBytesMessageTest {
         } catch (Exception e) {
             fail("should have thrown MessageFormatException");
         }
+
+        try {
+            bytesMessage.getBody(String.class);
+            fail("should have thrown MessageFormatException");
+        } catch (MessageFormatException mfe) {
+        } catch (Exception e) {
+            fail("should have thrown MessageFormatException");
+        }
+
+        try {
+            bytesMessage.getBody(Map.class);
+            fail("should have thrown MessageFormatException");
+        } catch (MessageFormatException mfe) {
+        } catch (Exception e) {
+            fail("should have thrown MessageFormatException");
+        }
+
+        try {
+            bytesMessage.getBody(List.class);
+            fail("should have thrown MessageFormatException");
+        } catch (MessageFormatException mfe) {
+        } catch (Exception e) {
+            fail("should have thrown MessageFormatException");
+        }
+
+        try {
+            bytesMessage.getBody(Array.class);
+            fail("should have thrown MessageFormatException");
+        } catch (MessageFormatException mfe) {
+        } catch (Exception e) {
+            fail("should have thrown MessageFormatException");
+        }
+
+        byte[] read1 = bytesMessage.getBody(byte[].class);
+        assertNotNull(read1);
+
+        byte[] read2 = (byte[]) bytesMessage.getBody(Object.class);
+        assertNotNull(read2);
     }
 
     //---------- Test for misc message methods -------------------------------//
