@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,30 +16,42 @@
  */
 package org.apache.qpid.jms.message;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.apache.qpid.jms.message.JmsMessageSupport.ACCEPTED;
+import static org.apache.qpid.jms.message.JmsMessageSupport.JMS_AMQP_ACK_TYPE;
+import static org.apache.qpid.jms.message.JmsMessageSupport.RELEASED;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
+import java.io.Serializable;
 import java.util.Enumeration;
-import java.util.concurrent.Callable;
+import java.util.Map;
+import java.util.UUID;
 
+import javax.jms.BytesMessage;
 import javax.jms.DeliveryMode;
 import javax.jms.JMSException;
+import javax.jms.MapMessage;
 import javax.jms.Message;
 import javax.jms.MessageFormatException;
 import javax.jms.MessageNotWriteableException;
+import javax.jms.ObjectMessage;
+import javax.jms.StreamMessage;
+import javax.jms.TextMessage;
 
+import org.apache.qpid.jms.JmsAcknowledgeCallback;
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsDestination;
+import org.apache.qpid.jms.JmsSession;
 import org.apache.qpid.jms.JmsTopic;
 import org.apache.qpid.jms.message.facade.JmsMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFactory;
-import org.junit.Before;
-import org.junit.Test;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -50,8 +62,6 @@ public class JmsMessageTest {
 
     private final JmsMessageFactory factory = new JmsTestMessageFactory();
 
-    protected boolean readOnlyMessage;
-
     private String jmsMessageID;
     private String jmsCorrelationID;
     private JmsDestination jmsDestination;
@@ -64,7 +74,7 @@ public class JmsMessageTest {
     private long jmsTimestamp;
     private long[] consumerIDs;
 
-    @Before
+    @BeforeEach
     public void setUp() throws Exception {
         this.jmsMessageID = "ID:TEST-ID:0:0:0:1";
         this.jmsCorrelationID = "testcorrelationid";
@@ -76,7 +86,6 @@ public class JmsMessageTest {
         this.jmsExpiration = 100000;
         this.jmsPriority = 5;
         this.jmsTimestamp = System.currentTimeMillis();
-        this.readOnlyMessage = false;
         this.consumerIDs = new long[3];
         for (int i = 0; i < this.consumerIDs.length; i++) {
             this.consumerIDs[i] = i;
@@ -88,9 +97,8 @@ public class JmsMessageTest {
         JmsMessage msg = factory.createMessage();
         assertFalse(msg.isReadOnlyBody());
         assertFalse(msg.isReadOnlyProperties());
-        msg.onSend(false, false, 0);
-        assertTrue(msg.isReadOnlyBody());
-        assertTrue(msg.isReadOnlyProperties());
+        msg.onSend(0);
+        assertTrue(msg.isReadOnly());
     }
 
     @Test
@@ -195,7 +203,6 @@ public class JmsMessageTest {
         this.jmsExpiration = 100000;
         this.jmsPriority = 5;
         this.jmsTimestamp = System.currentTimeMillis();
-        this.readOnlyMessage = false;
 
         JmsConnection connection = Mockito.mock(JmsConnection.class);
 
@@ -216,6 +223,7 @@ public class JmsMessageTest {
         msg1.setValidatePropertyNames(isValidate);
         JmsMessage msg2 = msg1.copy();
         assertEquals(msg1.getJMSMessageID(), msg2.getJMSMessageID());
+        assertTrue(msg2.isReadOnlyProperties());
         assertTrue(msg1.getJMSCorrelationID().equals(msg2.getJMSCorrelationID()));
         assertTrue(msg1.getJMSDestination().equals(msg2.getJMSDestination()));
         assertTrue(msg1.getJMSReplyTo().equals(msg2.getJMSReplyTo()));
@@ -305,6 +313,25 @@ public class JmsMessageTest {
         assertEquals(DeliveryMode.PERSISTENT, msg.getJMSDeliveryMode());
     }
 
+    @Test
+    public void testSetJMSDeliveryModeWithInvalidValue() throws JMSException {
+        JmsMessage msg = factory.createMessage();
+        assertEquals(Message.DEFAULT_DELIVERY_MODE, msg.getJMSDeliveryMode());
+        try {
+            msg.setJMSDeliveryMode(-1);
+            fail("Should have thrown an exception");
+        } catch (JMSException ex) {
+            LOG.debug("Caught expected exception: {}", ex.getMessage());
+        }
+        try {
+            msg.setJMSDeliveryMode(3);
+            fail("Should have thrown an exception");
+        } catch (JMSException ex) {
+            LOG.debug("Caught expected exception: {}", ex.getMessage());
+        }
+        assertEquals(Message.DEFAULT_DELIVERY_MODE, msg.getJMSDeliveryMode());
+    }
+
     @Test
     public void testGetAndSetMSRedelivered() throws JMSException {
         JmsMessage msg = factory.createMessage();
@@ -328,15 +355,23 @@ public class JmsMessageTest {
 
     @Test
     public void testGetAndSetJMSPriority() throws JMSException {
-        JmsMessage msg = factory.createMessage();
-        msg.setJMSPriority(this.jmsPriority);
-        assertTrue(msg.getJMSPriority() == this.jmsPriority);
+        JmsMessage message = factory.createMessage();
+        assertEquals(Message.DEFAULT_PRIORITY, message.getJMSPriority());
 
-        msg.setJMSPriority(-90);
-        assertEquals(0, msg.getJMSPriority());
+        try {
+            message.setJMSPriority(-1);
+            fail("Should have thrown an exception");
+        } catch (JMSException ex) {
+            LOG.debug("Caught expected exception: {}", ex.getMessage());
+        }
+        try {
+            message.setJMSPriority(10);
+            fail("Should have thrown an exception");
+        } catch (JMSException ex) {
+            LOG.debug("Caught expected exception: {}", ex.getMessage());
+        }
 
-        msg.setJMSPriority(90);
-        assertEquals(9, msg.getJMSPriority());
+        assertEquals(Message.DEFAULT_PRIORITY, message.getJMSPriority());
     }
 
     @Test
@@ -349,6 +384,27 @@ public class JmsMessageTest {
         assertNotNull(msg.getJMSMessageID());
     }
 
+    @Test
+    public void testClearPropertiesClearsReadOnly() throws Exception {
+        JmsMessage msg = factory.createMessage();
+        msg.onDispatch();
+
+        try {
+            msg.setObjectProperty("test", "value");
+            fail("should throw exception");
+        } catch (MessageNotWriteableException e) {
+            // Expected
+        }
+
+        assertTrue(msg.isReadOnlyProperties());
+
+        msg.clearProperties();
+
+        msg.setObjectProperty("test", "value");
+
+        assertFalse(msg.isReadOnlyProperties());
+    }
+
     @Test
     public void testClearPropertiesClearsFacadeGroupSequence() throws JMSException {
         JmsMessageFacade facade = Mockito.mock(JmsMessageFacade.class);
@@ -389,9 +445,9 @@ public class JmsMessageTest {
         assertTrue(testFacade.propertyExists(invalidPropName));
 
         if(!disableValidation) {
-            assertFalse("Property should be indicated to not exist", msg.propertyExists(invalidPropName));
+            assertFalse(msg.propertyExists(invalidPropName), "Property should be indicated to not exist");
         } else {
-            assertTrue("Property should be indicated to exist", msg.propertyExists(invalidPropName));
+            assertTrue(msg.propertyExists(invalidPropName), "Property should be indicated to exist");
         }
     }
 
@@ -519,10 +575,10 @@ public class JmsMessageTest {
             jmsxNameFound |= element.equals(jmsxName);
             headerNameFound1 |= element.equals(headerName);
         }
-        assertTrue("prop name not found", propNameFound);
-        assertTrue("jmsx prop name not found", jmsxNameFound);
+        assertTrue(propNameFound, "prop name not found");
+        assertTrue(jmsxNameFound, "jmsx prop name not found");
         // spec compliance, only non-'JMS header' props returned
-        assertFalse("header name should not have been found", headerNameFound1);
+        assertFalse(headerNameFound1, "header name should not have been found");
     }
 
     @Test
@@ -570,18 +626,18 @@ public class JmsMessageTest {
         }
 
         if (!disableValidation) {
-            assertFalse("Invalid prop name 1 was found", invalidPropName1Found);
-            assertFalse("Invalid prop name 2 was found", invalidPropName2Found);
+            assertFalse(invalidPropName1Found, "Invalid prop name 1 was found");
+            assertFalse(invalidPropName2Found, "Invalid prop name 2 was found");
         } else {
-            assertTrue("Invalid prop name 1 was not found", invalidPropName1Found);
-            assertTrue("Invalid prop name 2 was not found", invalidPropName2Found);
+            assertTrue(invalidPropName1Found, "Invalid prop name 1 was not found");
+            assertTrue(invalidPropName2Found, "Invalid prop name 2 was not found");
         }
-        assertTrue("valid prop name was not found", validPropNameFound);
+        assertTrue(validPropNameFound, "valid prop name was not found");
     }
 
     @Test
     @SuppressWarnings("rawtypes")
-    public void testGetAllPropertyNames() throws JMSException {
+    void testGetAllPropertyNames() throws JMSException {
         JmsMessage msg = factory.createMessage();
         String name1 = "floatProperty";
         msg.setFloatProperty(name1, 1.3f);
@@ -598,9 +654,9 @@ public class JmsMessageTest {
             found2 |= element.equals(name2);
             found3 |= element.equals(name3);
         }
-        assertTrue("prop name1 found", found1);
-        assertTrue("prop name2 found", found2);
-        assertTrue("prop name4 found", found3);
+        assertTrue(found1, "prop name1 found");
+        assertTrue(found2, "prop name2 found");
+        assertTrue(found3, "prop name4 found");
     }
 
     @Test
@@ -699,7 +755,7 @@ public class JmsMessageTest {
         JmsMessage msg = factory.createMessage();
         msg.setIntProperty("JMSXDeliveryCount", 1);
         int count = msg.getIntProperty("JMSXDeliveryCount");
-        assertTrue("expected delivery count = 1 - got: " + count, count == 1);
+        assertTrue(count == 1, "expected delivery count = 1 - got: " + count);
     }
 
     @Test
@@ -1133,42 +1189,19 @@ public class JmsMessageTest {
     }
 
     @Test
-    public void testAcknowledgeWitNoCallback() throws JMSException {
+    public void testAcknowledgeWithNoCallbackDoesNotThrow() throws JMSException {
         JmsMessage msg = factory.createMessage();
         msg.acknowledge();
     }
 
-    @SuppressWarnings("unchecked")
-    @Test
-    public void testAcknowledgeWitCallback() throws Exception {
-        Callable<Void> callback = Mockito.mock(Callable.class);
-        JmsMessage msg = factory.createMessage();
-        msg.setAcknowledgeCallback(callback);
-        msg.acknowledge();
-        Mockito.verify(callback).call();
-    }
-
-    @SuppressWarnings("unchecked")
-    @Test
-    public void testAcknowledgeWitCallbackThatThrows() throws Exception {
-        Callable<Void> callback = Mockito.mock(Callable.class);
-        Mockito.doThrow(new Exception()).when(callback).call();
-        JmsMessage msg = factory.createMessage();
-        msg.setAcknowledgeCallback(callback);
-        assertEquals(callback, msg.getAcknowledgeCallback());
-        try {
-            msg.acknowledge();
-            fail("Should have thrown.");
-        } catch (JMSException e) {
-        }
-    }
-
     //---- Test that message property getters throw expected exceptions ------//
 
     /**
      * When a property is not set, the behaviour of JMS specifies that it is equivalent to a null value,
      * and the primitive property accessors should behave in the same fashion as <primitive>.valueOf(String).
      * Test that this is the case.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testGetMissingPrimitivePropertyResultsInExpectedBehaviour() throws Exception {
@@ -1206,6 +1239,8 @@ public class JmsMessageTest {
      * {@link Character#isJavaLetter(char)} is true, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * beginning with a non-letter character.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNonLetterAsFirstCharacterThrowsIAE() throws Exception {
@@ -1223,6 +1258,8 @@ public class JmsMessageTest {
      * for which {@link Character#isJavaLetterOrDigit(char)} is true, as
      * described in {@link javax.jms.Message}. Verify an IAE is thrown if
      * setting a property continuing with a non-letter-or-digit character.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNonLetterOrDigitCharacterThrowsIAE() throws Exception {
@@ -1259,6 +1296,8 @@ public class JmsMessageTest {
      * Property 'identifiers' (i.e. names) are not allowed to be NULL, TRUE, or
      * FALSE, as described in {@link javax.jms.Message}. Verify an IAE is thrown
      * if setting a property with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameNULL() throws Exception {
@@ -1274,6 +1313,8 @@ public class JmsMessageTest {
      * Property 'identifiers' (i.e. names) are not allowed to be NULL, TRUE, or
      * FALSE, as described in {@link javax.jms.Message}. Verify an IAE is thrown
      * if setting a property with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameTRUE() throws Exception {
@@ -1289,6 +1330,8 @@ public class JmsMessageTest {
      * Property 'identifiers' (i.e. names) are not allowed to be NULL, TRUE, or
      * FALSE, as described in {@link javax.jms.Message}. Verify an IAE is thrown
      * if setting a property with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameFALSE() throws Exception {
@@ -1305,6 +1348,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameNOT() throws Exception {
@@ -1321,6 +1366,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameAND() throws Exception {
@@ -1337,6 +1384,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameOR() throws Exception {
@@ -1353,6 +1402,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameBETWEEN() throws Exception {
@@ -1369,6 +1420,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameLIKE() throws Exception {
@@ -1385,6 +1438,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameIN() throws Exception {
@@ -1401,6 +1456,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameIS() throws Exception {
@@ -1417,6 +1474,8 @@ public class JmsMessageTest {
      * BETWEEN, LIKE, IN, IS, or ESCAPE, as described in
      * {@link javax.jms.Message}. Verify an IAE is thrown if setting a property
      * with these values.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetPropertyWithNameESCAPE() throws Exception {
@@ -1450,6 +1509,358 @@ public class JmsMessageTest {
         doPropertyExistsWithInvalidNameTestImpl(true);
     }
 
+    //---------- Test ack type modifier property -------------//
+
+    /**
+     * Basic test that the JMS_AMQP_ACK_TYPE property is intercepted and has
+     * effect on messages with an acknowledgement callback. More detailed tests
+     * of usage and effect of this property is performed elsewhere.
+     *
+     * @throws Exception if an error occurs during the test.
+     */
+    @Test
+    public void testSetPropertyJMS_AMQP_ACK_TYPE() throws Exception {
+        JmsMessage message = factory.createMessage();
+        JmsSession session = Mockito.mock(JmsSession.class);
+        JmsAcknowledgeCallback callback = new JmsAcknowledgeCallback(session);
+        message.setAcknowledgeCallback(callback);
+
+        assertEquals(ACCEPTED, callback.getAckType(), "Unexpected ack type value");
+
+        message.setIntProperty(JMS_AMQP_ACK_TYPE, RELEASED);
+
+        assertEquals(RELEASED, callback.getAckType(), "Unexpected ack type value after setting prop");
+    }
+
+    //--------- Test isBodyAssignableTo method -------------------------------//
+
+    @Test
+    public void testMessageIsBodyAssignableTo() throws Exception {
+        Message message = factory.createMessage();
+
+        assertTrue(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Boolean.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+        assertTrue(message.isBodyAssignableTo(Map.class));
+    }
+
+    @Test
+    public void testTextMessageIsBodyAssignableTo() throws Exception {
+        JmsTextMessage message = factory.createTextMessage();
+
+        assertTrue(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Boolean.class));
+        assertTrue(message.isBodyAssignableTo(Map.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+
+        message.setText("test");
+
+        assertTrue(message.isBodyAssignableTo(String.class));
+        assertFalse(message.isBodyAssignableTo(Boolean.class));
+        assertFalse(message.isBodyAssignableTo(Map.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+    }
+
+    @Test
+    public void testStreamMessageIsBodyAssignableTo() throws Exception {
+        JmsStreamMessage message = factory.createStreamMessage();
+
+        assertFalse(message.isBodyAssignableTo(String.class));
+        assertFalse(message.isBodyAssignableTo(Boolean.class));
+        assertFalse(message.isBodyAssignableTo(Map.class));
+        assertFalse(message.isBodyAssignableTo(Object.class));
+
+        message.writeBoolean(false);
+
+        assertFalse(message.isBodyAssignableTo(String.class));
+        assertFalse(message.isBodyAssignableTo(Boolean.class));
+        assertFalse(message.isBodyAssignableTo(Map.class));
+        assertFalse(message.isBodyAssignableTo(Object.class));
+    }
+
+    @Test
+    public void testMapMessageIsBodyAssignableTo() throws Exception {
+        JmsMapMessage message = factory.createMapMessage();
+
+        assertTrue(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Boolean.class));
+        assertTrue(message.isBodyAssignableTo(Map.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+
+        message.setBoolean("Boolean", true);
+
+        assertFalse(message.isBodyAssignableTo(String.class));
+        assertFalse(message.isBodyAssignableTo(Boolean.class));
+        assertTrue(message.isBodyAssignableTo(Map.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+    }
+
+    @Test
+    public void testBytesMessageIsBodyAssignableTo() throws Exception {
+        JmsBytesMessage message = factory.createBytesMessage();
+
+        assertTrue(message.isBodyAssignableTo(byte[].class));
+        assertTrue(message.isBodyAssignableTo(Boolean.class));
+        assertTrue(message.isBodyAssignableTo(Map.class));
+        assertTrue(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+
+        message.writeBoolean(false);
+
+        // The message doesn't technically have a body until it is reset
+        message.reset();
+
+        assertTrue(message.isBodyAssignableTo(byte[].class));
+        assertFalse(message.isBodyAssignableTo(Boolean.class));
+        assertFalse(message.isBodyAssignableTo(Map.class));
+        assertFalse(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+    }
+
+    @Test
+    public void testObjectMessageIsBodyAssignableTo() throws Exception {
+        JmsObjectMessage message = factory.createObjectMessage();
+
+        assertTrue(message.isBodyAssignableTo(Boolean.class));
+        assertTrue(message.isBodyAssignableTo(Map.class));
+        assertTrue(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Serializable.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+
+        message.setObject(UUID.randomUUID());
+
+        assertFalse(message.isBodyAssignableTo(Boolean.class));
+        assertFalse(message.isBodyAssignableTo(Map.class));
+        assertFalse(message.isBodyAssignableTo(String.class));
+        assertTrue(message.isBodyAssignableTo(Serializable.class));
+        assertTrue(message.isBodyAssignableTo(Object.class));
+        assertTrue(message.isBodyAssignableTo(UUID.class));
+    }
+
+    //--------- Test for getBody method --------------------------------------//
+
+    @Test
+    public void testGetBodyOnMessage() throws Exception {
+        Message message = factory.createMessage();
+
+        assertNull(message.getBody(String.class));
+        assertNull(message.getBody(Boolean.class));
+        assertNull(message.getBody(byte[].class));
+        assertNull(message.getBody(Object.class));
+    }
+
+    @Test
+    public void testGetBodyOnTextMessage() throws Exception {
+        TextMessage message = factory.createTextMessage();
+
+        assertNull(message.getBody(String.class));
+        assertNull(message.getBody(Boolean.class));
+        assertNull(message.getBody(byte[].class));
+        assertNull(message.getBody(Object.class));
+
+        message.setText("test");
+
+        assertNotNull(message.getBody(String.class));
+        assertNotNull(message.getBody(Object.class));
+
+        try {
+            message.getBody(Boolean.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(Map.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(byte[].class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+    }
+
+    @Test
+    public void testGetBodyOnMapMessage() throws Exception {
+        MapMessage message = factory.createMapMessage();
+
+        assertNull(message.getBody(String.class));
+        assertNull(message.getBody(Boolean.class));
+        assertNull(message.getBody(byte[].class));
+        assertNull(message.getBody(Object.class));
+
+        message.setString("test", "test");
+
+        assertNotNull(message.getBody(Map.class));
+        assertNotNull(message.getBody(Object.class));
+
+        try {
+            message.getBody(Boolean.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(String.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(byte[].class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+    }
+
+    @Test
+    public void testGetBodyOnObjectMessage() throws Exception {
+        ObjectMessage message = factory.createObjectMessage();
+
+        assertNull(message.getBody(String.class));
+        assertNull(message.getBody(Boolean.class));
+        assertNull(message.getBody(byte[].class));
+        assertNull(message.getBody(Serializable.class));
+        assertNull(message.getBody(Object.class));
+
+        message.setObject(UUID.randomUUID());
+
+        assertNotNull(message.getBody(UUID.class));
+        assertNotNull(message.getBody(Serializable.class));
+        assertNotNull(message.getBody(Object.class));
+
+        try {
+            message.getBody(Boolean.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(String.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(byte[].class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+    }
+
+    @Test
+    public void testGetBodyOnBytesMessage() throws Exception {
+        BytesMessage message = factory.createBytesMessage();
+
+        assertNull(message.getBody(String.class));
+        assertNull(message.getBody(Boolean.class));
+        assertNull(message.getBody(byte[].class));
+        assertNull(message.getBody(Object.class));
+
+        message.clearBody();
+
+        message.writeUTF("test");
+        message.reset();
+
+        assertNotNull(message.getBody(byte[].class));
+        assertNotNull(message.getBody(Object.class));
+
+        try {
+            message.getBody(Boolean.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(Map.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(String.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+    }
+
+    @Test
+    public void testGetBodyOnStreamMessage() throws Exception {
+        StreamMessage message = factory.createStreamMessage();
+
+        try {
+            message.getBody(Object.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(Boolean.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(String.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(byte[].class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        message.writeBoolean(false);
+
+        try {
+            message.getBody(Object.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(Boolean.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(String.class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+
+        try {
+            message.getBody(byte[].class);
+            fail("Should have thrown an exception");
+        } catch (MessageFormatException mfe) {
+            LOG.info("caught expected MessageFormatException");
+        }
+    }
+
     //--------- Test support method ------------------------------------------//
 
     private void assertGetMissingPropertyThrowsNumberFormatException(JmsMessage testMessage, String propertyName, Class<?> clazz) throws JMSException {
