@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,15 +16,16 @@
  */
 package org.apache.qpid.jms.message;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNotSame;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNotSame;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
+import javax.jms.DeliveryMode;
 import javax.jms.Destination;
 import javax.jms.JMSException;
 import javax.jms.MessageEOFException;
@@ -45,7 +46,7 @@ import org.apache.qpid.jms.message.foreign.ForeignJmsMessage;
 import org.apache.qpid.jms.message.foreign.ForeignJmsObjectMessage;
 import org.apache.qpid.jms.message.foreign.ForeignJmsStreamMessage;
 import org.apache.qpid.jms.message.foreign.ForeignJmsTextMessage;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 
 /**
@@ -55,23 +56,18 @@ public class JmsMessageTransformationTest {
 
     private static final String DESTINATION_NAME = "Test-Destination-Name";
 
-    @Test
-    public void testJmsDestinationCreate() throws JMSException {
-        new JmsMessageTransformation();
-    }
-
     //---------- Test Message Transformation ---------------------------------//
 
     @Test
-    public void testTransformJmsMessageCopies() throws JMSException {
-        JmsMessage source = new JmsMessage(new JmsTestMessageFacade());
+    public void testTransformJmsMessage() throws JMSException {
+        JmsMessage orig = new JmsMessage(new JmsTestMessageFacade());
 
-        source.setJMSMessageID("ID:CONNECTION:1:1");
+        orig.setJMSMessageID("ID:CONNECTION:1:1");
 
-        JmsMessage copy = JmsMessageTransformation.transformMessage(createMockJmsConnection(), source);
-        assertNotNull(copy.getJMSMessageID());
-        assertEquals(source, copy);
-        assertNotSame(source, copy);
+        JmsMessage transformed = JmsMessageTransformation.transformMessage(createMockJmsConnection(), orig);
+        assertNotNull(transformed.getJMSMessageID());
+        assertEquals(orig, transformed);
+        assertNotSame(orig, transformed);
     }
 
     @Test
@@ -276,6 +272,41 @@ public class JmsMessageTransformationTest {
 
     //---------- Test Generic Property Copy ----------------------------------//
 
+    @Test
+    public void testJMSMessageHeadersAreCopied() throws JMSException {
+        JmsMessage source = new JmsMessage(new JmsTestMessageFacade());
+        JmsMessage target = new JmsMessage(new JmsTestMessageFacade());
+
+        JmsTopic destination = new JmsTopic(DESTINATION_NAME);
+        JmsTopic replyTo = new JmsTopic("ReplyTp:" + DESTINATION_NAME);
+
+        source.setJMSMessageID("ID:TEST");
+        source.setJMSCorrelationID("ID:CORRELATION");
+        source.setJMSReplyTo(replyTo);
+        source.setJMSDestination(destination);
+        source.setJMSDeliveryMode(DeliveryMode.NON_PERSISTENT);
+        source.setJMSDeliveryTime(10000);
+        source.setJMSRedelivered(true);
+        source.setJMSType("test-type");
+        source.setJMSExpiration(15000);
+        source.setJMSPriority(7);
+        source.setJMSTimestamp(5000);
+
+        JmsMessageTransformation.copyProperties(createMockJmsConnection(), source, target);
+
+        assertEquals("ID:TEST" , target.getJMSMessageID());
+        assertEquals("ID:CORRELATION", target.getJMSCorrelationID());
+        assertEquals(replyTo, target.getJMSReplyTo());
+        assertEquals(destination, target.getJMSDestination());
+        assertEquals(DeliveryMode.NON_PERSISTENT, target.getJMSDeliveryMode());
+        assertEquals(10000, target.getJMSDeliveryTime());
+        assertEquals(true, target.getJMSRedelivered());
+        assertEquals("test-type", target.getJMSType());
+        assertEquals(15000, target.getJMSExpiration());
+        assertEquals(7, target.getJMSPriority());
+        assertEquals(5000, target.getJMSTimestamp());
+    }
+
     @Test
     public void testJMSMessagePropertiesAreCopied() throws JMSException {
         JmsMessage source = new JmsMessage(new JmsTestMessageFacade());
@@ -370,7 +401,7 @@ public class JmsMessageTransformationTest {
         assertNotNull(transformed);
         assertTrue(transformed.isTopic());
         assertFalse(transformed.isTemporary());
-        assertEquals(DESTINATION_NAME, transformed.getName());
+        assertEquals(DESTINATION_NAME, transformed.getAddress());
     }
 
     @Test
@@ -382,7 +413,7 @@ public class JmsMessageTransformationTest {
         assertNotNull(transformed);
         assertTrue(transformed.isQueue());
         assertFalse(transformed.isTemporary());
-        assertEquals(DESTINATION_NAME, transformed.getName());
+        assertEquals(DESTINATION_NAME, transformed.getAddress());
     }
 
     @Test
@@ -400,7 +431,7 @@ public class JmsMessageTransformationTest {
         assertNotNull(transformed);
         assertTrue(transformed.isTopic());
         assertFalse(transformed.isTemporary());
-        assertEquals(DESTINATION_NAME, transformed.getName());
+        assertEquals(DESTINATION_NAME, transformed.getAddress());
     }
 
     @Test
@@ -411,7 +442,7 @@ public class JmsMessageTransformationTest {
         assertNotNull(transformed);
         assertTrue(transformed.isQueue());
         assertFalse(transformed.isTemporary());
-        assertEquals(DESTINATION_NAME, transformed.getName());
+        assertEquals(DESTINATION_NAME, transformed.getAddress());
     }
 
     @Test
@@ -422,7 +453,7 @@ public class JmsMessageTransformationTest {
         assertNotNull(transformed);
         assertTrue(transformed.isQueue());
         assertTrue(transformed.isTemporary());
-        assertEquals(DESTINATION_NAME, transformed.getName());
+        assertEquals(DESTINATION_NAME, transformed.getAddress());
     }
 
     @Test
@@ -433,7 +464,7 @@ public class JmsMessageTransformationTest {
         assertNotNull(transformed);
         assertTrue(transformed.isTopic());
         assertTrue(transformed.isTemporary());
-        assertEquals(DESTINATION_NAME, transformed.getName());
+        assertEquals(DESTINATION_NAME, transformed.getAddress());
     }
 
     //---------- Mocking support ---------------------------------------------//
