@@ -22,12 +22,18 @@ import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.both;
 import static org.hamcrest.Matchers.greaterThanOrEqualTo;
 import static org.hamcrest.Matchers.lessThanOrEqualTo;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyLong;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.nullable;
 
 import java.nio.charset.StandardCharsets;
 import java.util.Collections;
@@ -35,6 +41,7 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
 
+import javax.jms.BytesMessage;
 import javax.jms.CompletionListener;
 import javax.jms.DeliveryMode;
 import javax.jms.Destination;
@@ -45,9 +52,12 @@ import javax.jms.InvalidDestinationRuntimeException;
 import javax.jms.JMSException;
 import javax.jms.JMSProducer;
 import javax.jms.JMSRuntimeException;
+import javax.jms.MapMessage;
 import javax.jms.Message;
 import javax.jms.MessageFormatRuntimeException;
+import javax.jms.ObjectMessage;
 import javax.jms.Queue;
+import javax.jms.TextMessage;
 
 import org.apache.qpid.jms.JmsConnection;
 import org.apache.qpid.jms.JmsConnectionTestSupport;
@@ -62,10 +72,11 @@ import org.apache.qpid.jms.message.JmsOutboundMessageDispatch;
 import org.apache.qpid.jms.meta.JmsSessionId;
 import org.apache.qpid.jms.provider.mock.MockRemotePeer;
 import org.hamcrest.Matcher;
-import org.junit.After;
-import org.junit.Before;
-import org.junit.Test;
-import org.mockito.Matchers;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.TestInfo;
+import org.junit.jupiter.api.Timeout;
 import org.mockito.Mockito;
 
 /**
@@ -110,16 +121,16 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
     private final String JMS_TYPE_STRING = "TestType";
 
     @Override
-    @Before
-    public void setUp() throws Exception {
-        super.setUp();
+    @BeforeEach
+    public void setUp(TestInfo testInfo) throws Exception {
+        super.setUp(testInfo);
 
         remotePeer.start();
         context = createJMSContextToMockProvider();
     }
 
     @Override
-    @After
+    @AfterEach
     public void tearDown() throws Exception {
         try {
             context.close();
@@ -782,7 +793,8 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         assertEquals(DeliveryMode.NON_PERSISTENT, producer.getDeliveryMode());
     }
 
-    @Test(timeout = 10000)
+    @Test
+    @Timeout(10)
     public void testDeliveryModeConfigurationWithInvalidMode() throws Exception {
         JMSProducer producer = context.createProducer();
 
@@ -843,7 +855,8 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         assertEquals(4, producer.getPriority());
     }
 
-    @Test(timeout = 10000)
+    @Test
+    @Timeout(10)
     public void testPriorityConfigurationWithInvalidPriorityValues() throws Exception {
         JMSProducer producer = context.createProducer();
 
@@ -999,18 +1012,18 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         doTestSendAppliesDeliveryModeWithMessageBody(UUID.class);
     }
 
-    public void doTestSendAppliesDeliveryModeWithMessageBody(Class<?> bodyType) throws JMSException {
+    private void doTestSendAppliesDeliveryModeWithMessageBody(Class<?> bodyType) throws JMSException {
         JMSProducer producer = context.createProducer();
 
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
-        producer.send(JMS_DESTINATION, "text");
+        sendWithBodyOfType(producer, bodyType);
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
         assertEquals(DeliveryMode.PERSISTENT, message.getJMSDeliveryMode());
 
         producer.setDeliveryMode(DeliveryMode.NON_PERSISTENT);
-        producer.send(JMS_DESTINATION, "text");
+        sendWithBodyOfType(producer, bodyType);
         envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         message = envelope.getMessage();
@@ -1201,9 +1214,25 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof TextMessage);
         assertEquals(bodyValue, message.getBody(String.class));
     }
 
+    @Test
+    public void testStringNullBodyGivesEmptyMessage() throws JMSException {
+        JMSProducer producer = context.createProducer();
+
+        final String nullStringBody = null;
+        producer.send(JMS_DESTINATION, nullStringBody);
+
+        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
+        assertNotNull(envelope);
+
+        JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof TextMessage);
+        assertNull(message.getBody(String.class));
+    }
+
     @Test
     public void testMapBodyIsApplied() throws JMSException {
         JMSProducer producer = context.createProducer();
@@ -1217,9 +1246,25 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof MapMessage);
         assertEquals(bodyValue, message.getBody(Map.class));
     }
 
+    @Test
+    public void testMapNullBodyGivesEmptyMessage() throws JMSException {
+        JMSProducer producer = context.createProducer();
+
+        final Map<String, Object> nullMapBody = null;
+        producer.send(JMS_DESTINATION, nullMapBody);
+
+        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
+        assertNotNull(envelope);
+
+        JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof MapMessage);
+        assertNull(message.getBody(Map.class));
+    }
+
     @Test
     public void testBytesBodyIsApplied() throws JMSException {
         JMSProducer producer = context.createProducer();
@@ -1230,6 +1275,7 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof BytesMessage);
 
         byte[] payload = message.getBody(byte[].class);
         assertNotNull(payload);
@@ -1240,6 +1286,21 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         }
     }
 
+    @Test
+    public void testBytesNullBodyGivesEmptyMessage() throws JMSException {
+        JMSProducer producer = context.createProducer();
+
+        final byte[] nullBytesBody = null;
+        producer.send(JMS_DESTINATION, nullBytesBody);
+
+        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
+        assertNotNull(envelope);
+
+        JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof BytesMessage);
+        assertNull(message.getBody(byte[].class));
+    }
+
     @Test
     public void testSerializableBodyIsApplied() throws JMSException {
         JMSProducer producer = context.createProducer();
@@ -1250,9 +1311,25 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
         assertNotNull(envelope);
         JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof ObjectMessage);
         assertEquals(bodyValue, message.getBody(UUID.class));
     }
 
+    @Test
+    public void testSerializableNullBodyGivesEmptyMessage() throws JMSException {
+        JMSProducer producer = context.createProducer();
+
+        final UUID nullSerializableBody = null;
+        producer.send(JMS_DESTINATION, nullSerializableBody);
+
+        JmsOutboundMessageDispatch envelope = remotePeer.getLastReceivedMessage();
+        assertNotNull(envelope);
+
+        JmsMessage message = envelope.getMessage();
+        assertTrue(message instanceof ObjectMessage);
+        assertNull(message.getBody(byte[].class));
+    }
+
     //----- Test for conversions to JMSRuntimeException ----------------------//
 
     @Test
@@ -1264,7 +1341,7 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         Mockito.when(session.createTemporaryQueue()).thenReturn(new JmsTemporaryQueue());
         Mockito.when(session.createMessage()).thenReturn(message);
 
-        Mockito.doThrow(IllegalStateException.class).when(message).setJMSCorrelationID(Matchers.anyString());
+        Mockito.doThrow(IllegalStateException.class).when(message).setJMSCorrelationID(anyString());
 
         JmsProducer producer = new JmsProducer(session, messageProducer);
 
@@ -1338,7 +1415,7 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
         Mockito.when(session.createTemporaryQueue()).thenReturn(new JmsTemporaryQueue());
         Mockito.when(session.createMessage()).thenReturn(Mockito.mock(Message.class));
 
-        Mockito.doThrow(IllegalStateException.class).when(session).createTextMessage(Matchers.anyString());
+        Mockito.doThrow(IllegalStateException.class).when(session).createTextMessage(anyString());
 
         JmsProducer producer = new JmsProducer(session, messageProducer);
 
@@ -1383,9 +1460,9 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
 
         Mockito.doThrow(new InvalidDestinationException("ide"))
                 .when(mockSession)
-                .send(Mockito.any(JmsMessageProducer.class), Mockito.any(Destination.class), Mockito.any(Message.class),
-                      Mockito.any(int.class), Mockito.any(int.class), Mockito.any(long.class), Mockito.any(boolean.class),
-                      Mockito.any(boolean.class), Mockito.any(long.class), Mockito.any(CompletionListener.class));
+                .send(any(JmsMessageProducer.class), nullable(Destination.class), any(Message.class),
+                      anyInt(), anyInt(), anyLong(), anyBoolean(),
+                      anyBoolean(), anyLong(), nullable(CompletionListener.class));
 
         JmsProducer producer = new JmsProducer(mockSession, mockMessageProducer);
 
@@ -1394,9 +1471,9 @@ public class JmsProducerTest extends JmsConnectionTestSupport {
             fail("Should have thrown an InvalidDestinationRuntimeException");
         } catch (InvalidDestinationRuntimeException idre) {}
 
-        Mockito.verify(mockSession).send(Mockito.any(JmsMessageProducer.class), Mockito.any(Destination.class), Mockito.any(Message.class),
-                Mockito.any(int.class), Mockito.any(int.class), Mockito.any(long.class), Mockito.any(boolean.class),
-                Mockito.any(boolean.class), Mockito.any(long.class), Mockito.any(CompletionListener.class));
+        Mockito.verify(mockSession).send(any(JmsMessageProducer.class), nullable(Destination.class), any(Message.class),
+                anyInt(), anyInt(), anyLong(), anyBoolean(),
+                anyBoolean(), anyLong(), nullable(CompletionListener.class));
     }
 
     //----- Internal Support -------------------------------------------------//
