@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -17,16 +17,13 @@
 package org.apache.qpid.jms.provider.amqp.message;
 
 import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.JMS_BYTES_MESSAGE;
-import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.JMS_MSG_TYPE;
-import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.getSymbol;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertSame;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-import io.netty.buffer.ByteBufInputStream;
-import io.netty.buffer.ByteBufOutputStream;
-import io.netty.buffer.Unpooled;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertSame;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.io.IOException;
 import java.io.InputStream;
@@ -34,7 +31,6 @@ import java.io.OutputStream;
 import java.lang.reflect.Field;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.Map;
 
 import org.apache.qpid.proton.amqp.Binary;
 import org.apache.qpid.proton.amqp.Symbol;
@@ -42,11 +38,16 @@ import org.apache.qpid.proton.amqp.messaging.AmqpSequence;
 import org.apache.qpid.proton.amqp.messaging.AmqpValue;
 import org.apache.qpid.proton.amqp.messaging.Data;
 import org.apache.qpid.proton.amqp.messaging.MessageAnnotations;
+import org.apache.qpid.proton.amqp.messaging.Properties;
 import org.apache.qpid.proton.amqp.messaging.Section;
 import org.apache.qpid.proton.message.Message;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 
+import io.netty.buffer.ByteBufInputStream;
+import io.netty.buffer.ByteBufOutputStream;
+import io.netty.buffer.Unpooled;
+
 /**
  * Tests for class AmqpJmsBytesMessageFacade
  */
@@ -57,18 +58,13 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
     // ---------- Test initial state of newly created message -----------------//
 
     @Test
-    public void testNewMessageContainsMessageTypeAnnotation() throws Exception {
+    public void testNewMessageDoesNotContainMessageTypeAnnotation() throws Exception {
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
 
-        Message protonMessage = amqpBytesMessageFacade.getAmqpMessage();
-        MessageAnnotations annotations = protonMessage.getMessageAnnotations();
-        Map<Symbol, Object> annotationsMap = annotations.getValue();
+        MessageAnnotations annotations = amqpBytesMessageFacade.getMessageAnnotations();
 
-        assertNotNull("MessageAnnotations section was not present", annotations);
-        assertNotNull("MessageAnnotations section value was not present", annotationsMap);
+        assertNull(annotations, "MessageAnnotations section was present");
 
-        assertTrue("expected message type annotation to be present", annotationsMap.containsKey(AmqpMessageSupport.getSymbol(JMS_MSG_TYPE)));
-        assertEquals("unexpected value for message type annotation value", JMS_BYTES_MESSAGE, annotationsMap.get(getSymbol(JMS_MSG_TYPE)));
         assertEquals(JMS_BYTES_MESSAGE, amqpBytesMessageFacade.getJmsMsgType());
     }
 
@@ -80,25 +76,14 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         assertNotNull(byteArrayInputStream);
 
         // try to read a byte, it should return -1 bytes read, i.e EOS.
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, byteArrayInputStream.read(new byte[1]));
+        assertEquals(END_OF_STREAM, byteArrayInputStream.read(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
     public void testGetBodyLengthUsingNewMessage() throws Exception {
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
 
-        assertEquals("Message reports unexpected length", 0, amqpBytesMessageFacade.getBodyLength());
-    }
-
-    @Test
-    public void testNewMessageHasContentType() throws Exception {
-        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
-        Message protonMessage = amqpBytesMessageFacade.getAmqpMessage();
-
-        assertNotNull(protonMessage);
-        String contentType = protonMessage.getContentType();
-        assertNotNull("content type should be set", contentType);
-        assertEquals("application/octet-stream", contentType);
+        assertEquals(0, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
     }
 
     // ---------- test for normal message operations -------------------------//
@@ -113,7 +98,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         amqpBytesMessageFacade.reset();
 
-        assertEquals("Message reports unexpected length", bytes.length, amqpBytesMessageFacade.getBodyLength());
+        assertEquals(bytes.length, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
     }
 
     @Test
@@ -122,7 +107,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         OutputStream os1 = amqpBytesMessageFacade.getOutputStream();
         OutputStream os2 = amqpBytesMessageFacade.getOutputStream();
-        assertSame("Got different output streams", os1, os2);
+        assertSame(os1, os2, "Got different output streams");
     }
 
     @Test
@@ -131,20 +116,20 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         InputStream is1 = amqpBytesMessageFacade.getInputStream();
         InputStream is2 = amqpBytesMessageFacade.getInputStream();
-        assertSame("Got different input streams", is1, is2);
+        assertSame(is1, is2, "Got different input streams");
     }
 
     /**
      * Test that copying a new messages which has been written to creates the
      * non-empty data section of the underlying message.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testCopyOnPopulatedNewMessageCreatesDataSection() throws Exception {
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
-        Message protonMessage = amqpBytesMessageFacade.getAmqpMessage();
 
-        assertNotNull("underlying proton message was null", protonMessage);
-        assertDataBodyAsExpected(protonMessage, 0);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
 
         byte[] bytes = "myBytes".getBytes();
         OutputStream os = amqpBytesMessageFacade.getOutputStream();
@@ -152,26 +137,81 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         AmqpJmsBytesMessageFacade copy = amqpBytesMessageFacade.copy();
 
-        assertDataBodyAsExpected(protonMessage, bytes.length);
-        assertDataBodyAsExpected(copy.getAmqpMessage(), bytes.length);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), bytes.length);
+        assertDataBodyAsExpected(copy.getBody(), bytes.length);
     }
 
     /**
      * Test that copying a new messages which has not been written to creates the
      * (empty) data section of the underlying message on the copy.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testCopyOfNewMessageDoesNotCreateDataSection() throws Exception {
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
-        Message origAmqpMessage = amqpBytesMessageFacade.getAmqpMessage();
 
-        assertNotNull("underlying proton message was null", origAmqpMessage);
-        assertDataBodyAsExpected(origAmqpMessage, 0);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
 
         AmqpJmsBytesMessageFacade copy = amqpBytesMessageFacade.copy();
 
-        assertDataBodyAsExpected(origAmqpMessage, 0);
-        assertDataBodyAsExpected(copy.getAmqpMessage(), 0);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
+        assertDataBodyAsExpected(copy.getBody(), 0);
+    }
+
+    @Test
+    public void testCopyOfContentType() throws Exception {
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade1 = createNewBytesMessageFacade();
+        AmqpJmsBytesMessageFacade copy1 = amqpBytesMessageFacade1.copy();
+        assertNull(copy1.getContentType());
+
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade2 = createNewBytesMessageFacade();
+        Symbol contentType = Symbol.valueOf("content-type");
+        amqpBytesMessageFacade2.setContentType(contentType);
+
+        AmqpJmsBytesMessageFacade copy2 = amqpBytesMessageFacade2.copy();
+        assertEquals(contentType, copy2.getContentType());
+    }
+
+    @Test
+    public void testMessageToSendHasContentTypeSet() throws Exception {
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
+        amqpBytesMessageFacade.onSend(0);
+
+        Properties properties = amqpBytesMessageFacade.getProperties();
+        assertNotNull(properties);
+        assertNotNull(properties.getContentType());
+
+        String contentType = properties.getContentType().toString();
+        assertNotNull(contentType, "content type should be set");
+        assertEquals("application/octet-stream", contentType);
+    }
+
+    /**
+     * Test that copying a new messages which has a body and the copy has getOutputStream
+     * called which clears the message body doesn't affect the original.
+     *
+     * @throws Exception if an error occurs during the test.
+     */
+    @Test
+    public void testGetOutputStreamOnCopiedMessageLeavesOriginalUntouched() throws Exception {
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
+
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
+
+        byte[] bytes = "myBytes".getBytes();
+        OutputStream os = amqpBytesMessageFacade.getOutputStream();
+        os.write(bytes);
+
+        AmqpJmsBytesMessageFacade copy = amqpBytesMessageFacade.copy();
+
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), bytes.length);
+        assertDataBodyAsExpected(copy.getBody(), bytes.length);
+
+        copy.getOutputStream();
+
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), bytes.length);
+        assertDataBodyAsExpected(copy.getBody(), 0);
     }
 
     @Test
@@ -184,10 +224,10 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         amqpBytesMessageFacade.clearBody();
 
-        assertTrue("Expected no message content from facade", amqpBytesMessageFacade.getBodyLength() == 0);
-        assertEquals("Expected no data from facade, but got some", END_OF_STREAM, amqpBytesMessageFacade.getInputStream().read(new byte[1]));
+        assertTrue(amqpBytesMessageFacade.getBodyLength() == 0, "Expected no message content from facade");
+        assertEquals(END_OF_STREAM, amqpBytesMessageFacade.getInputStream().read(new byte[1]), "Expected no data from facade, but got some");
 
-        assertDataBodyAsExpected(amqpBytesMessageFacade.getAmqpMessage(), 0);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
     }
 
     @Test
@@ -203,9 +243,9 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         amqpBytesMessageFacade.clearBody();
 
-        assertEquals("Expected no data from facade, but got some", END_OF_STREAM, amqpBytesMessageFacade.getInputStream().read(new byte[1]));
+        assertEquals(END_OF_STREAM, amqpBytesMessageFacade.getInputStream().read(new byte[1]), "Expected no data from facade, but got some");
 
-        assertDataBodyAsExpected(amqpBytesMessageFacade.getAmqpMessage(), 0);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
     }
 
     @Test
@@ -221,7 +261,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         amqpBytesMessageFacade.clearBody();
 
-        assertDataBodyAsExpected(amqpBytesMessageFacade.getAmqpMessage(), 0);
+        assertDataBodyAsExpected(amqpBytesMessageFacade.getBody(), 0);
     }
 
     @Test
@@ -261,7 +301,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         assertNotNull(byteArrayInputStream);
 
         // try to read a byte, it should return -1 bytes read, i.e EOS.
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, byteArrayInputStream.read(new byte[1]));
+        assertEquals(END_OF_STREAM, byteArrayInputStream.read(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
@@ -271,7 +311,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         message.setBody(new Data(new Binary(new byte[length])));
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Message reports unexpected length", length, amqpBytesMessageFacade.getBodyLength());
+        assertEquals(length, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
     }
 
     @Test
@@ -281,7 +321,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         message.setBody(new AmqpValue(new Binary(new byte[length])));
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Message reports unexpected length", length, amqpBytesMessageFacade.getBodyLength());
+        assertEquals(length, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
     }
 
     @Test
@@ -290,7 +330,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         message.setBody(new AmqpValue(new Binary(new byte[0])));
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Message reports unexpected length", 0, amqpBytesMessageFacade.getBodyLength());
+        assertEquals(0, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
     }
 
     @Test
@@ -299,7 +339,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         message.setBody(new AmqpValue(null));
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Message reports unexpected length", 0, amqpBytesMessageFacade.getBodyLength());
+        assertEquals(0, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
     }
 
     @Test
@@ -318,7 +358,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         assertTrue(Arrays.equals(bytes, receivedBytes));
 
         // verify no more bytes remain, i.e EOS
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, bytesStream.read(new byte[1]));
+        assertEquals(END_OF_STREAM, bytesStream.read(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
@@ -338,7 +378,7 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         assertTrue(Arrays.equals(bytes, receivedBytes));
 
         // verify no more bytes remain, i.e EOS
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, bytesStream.read(new byte[1]));
+        assertEquals(END_OF_STREAM, bytesStream.read(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
@@ -350,8 +390,8 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         InputStream bytesStream = amqpBytesMessageFacade.getInputStream();
         assertNotNull(bytesStream);
 
-        assertEquals("Message reports unexpected length", 0, amqpBytesMessageFacade.getBodyLength());
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, bytesStream.read(new byte[1]));
+        assertEquals(0, amqpBytesMessageFacade.getBodyLength(), "Message reports unexpected length");
+        assertEquals(END_OF_STREAM, bytesStream.read(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
@@ -399,6 +439,8 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
     /**
      * Test that setting bytes on a received message results in the expected content in the body section
      * of the underlying message and returned by a new InputStream requested from the message.
+     *
+     * @throws Exception if an error occurs during the test.
      */
     @Test
     public void testSetGetBodyOnReceivedMessage() throws Exception {
@@ -408,7 +450,6 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         Message message = Message.Factory.create();
         message.setBody(new Data(new Binary(orig)));
         AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
-        Message protonMessage = amqpBytesMessageFacade.getAmqpMessage();
 
         OutputStream os = amqpBytesMessageFacade.getOutputStream();
         os.write(replacement);
@@ -417,19 +458,19 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
         // Retrieve the new Binary from the underlying message, check they match
         // (the backing arrays may be different length so not checking arrayEquals)
-        Data body = (Data) protonMessage.getBody();
-        assertEquals("Underlying message data section did not contain the expected bytes", new Binary(replacement), body.getValue());
+        Data body = (Data) amqpBytesMessageFacade.getBody();
+        assertEquals(new Binary(replacement), body.getValue(), "Underlying message data section did not contain the expected bytes");
 
-        assertEquals("expected body length to match replacement bytes", replacement.length, amqpBytesMessageFacade.getBodyLength());
+        assertEquals(replacement.length, amqpBytesMessageFacade.getBodyLength(), "expected body length to match replacement bytes");
 
         // retrieve the new bytes via an InputStream, check they match expected
         byte[] receivedBytes = new byte[replacement.length];
         InputStream bytesStream = amqpBytesMessageFacade.getInputStream();
         bytesStream.read(receivedBytes);
-        assertTrue("Retrieved bytes from input steam did not match expected bytes", Arrays.equals(replacement, receivedBytes));
+        assertTrue(Arrays.equals(replacement, receivedBytes), "Retrieved bytes from input steam did not match expected bytes");
 
         // verify no more bytes remain, i.e EOS
-        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, bytesStream.read(new byte[1]));
+        assertEquals(END_OF_STREAM, bytesStream.read(new byte[1]), "Expected input stream to be at end but data was returned");
     }
 
     @Test
@@ -492,15 +533,82 @@ public class AmqpJmsBytesMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
         amqpBytesMessageFacade.reset();
     }
 
+    //--------- hasBody tests ---------------
+
+    @Test
+    public void testHasBodyOnNewMessage() throws Exception {
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
+
+        assertFalse(amqpBytesMessageFacade.hasBody());
+    }
+
+    @Test
+    public void testHasBodyWithContent() throws Exception {
+        byte[] bodyBytes = "myOrigBytes".getBytes();
+
+        Message message = Message.Factory.create();
+        message.setBody(new Data(new Binary(bodyBytes)));
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
+
+        assertTrue(amqpBytesMessageFacade.hasBody());
+    }
+
+    @Test
+    public void testHasBodyAfterClear() throws Exception {
+        byte[] bodyBytes = "myOrigBytes".getBytes();
+
+        Message message = Message.Factory.create();
+        message.setBody(new Data(new Binary(bodyBytes)));
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
+
+        assertTrue(amqpBytesMessageFacade.hasBody());
+
+        amqpBytesMessageFacade.clearBody();
+
+        assertFalse(amqpBytesMessageFacade.hasBody());
+    }
+
+    @Test
+    public void testHasBodyWithActiveInputStream() throws Exception {
+        byte[] bodyBytes = "myOrigBytes".getBytes();
+
+        Message message = Message.Factory.create();
+        message.setBody(new Data(new Binary(bodyBytes)));
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createReceivedBytesMessageFacade(createMockAmqpConsumer(), message);
+
+        assertTrue(amqpBytesMessageFacade.hasBody());
+
+        amqpBytesMessageFacade.getInputStream();
+
+        assertTrue(amqpBytesMessageFacade.hasBody());
+    }
+
+    @Test
+    public void testHasBodyWithActiveOutputStream() throws Exception {
+        AmqpJmsBytesMessageFacade amqpBytesMessageFacade = createNewBytesMessageFacade();
+
+        assertFalse(amqpBytesMessageFacade.hasBody());
+
+        OutputStream output = amqpBytesMessageFacade.getOutputStream();
+
+        assertFalse(amqpBytesMessageFacade.hasBody());
+
+        output.write(1);
+
+        // Body exists after some data written.
+        assertTrue(amqpBytesMessageFacade.hasBody());
+        amqpBytesMessageFacade.reset();
+        assertTrue(amqpBytesMessageFacade.hasBody());
+    }
+
     //--------- utility methods ----------
 
-    private void assertDataBodyAsExpected(Message protonMessage, int length) {
-        Section body = protonMessage.getBody();
-        assertNotNull("Expected body section to be present", body);
-        assertEquals("Unexpected body section type", Data.class, protonMessage.getBody().getClass());
+    private void assertDataBodyAsExpected(Section body, int length) {
+        assertNotNull(body, "Expected body section to be present");
+        assertEquals(Data.class, body.getClass(), "Unexpected body section type");
         Binary value = ((Data) body).getValue();
         assertNotNull(value);
-        assertEquals("Unexpected body length", length, value.getLength());
+        assertEquals(length, value.getLength(), "Unexpected body length");
     }
 
     private InputStream substituteMockInputStream(AmqpJmsBytesMessageFacade bytesMessage) throws NoSuchFieldException, SecurityException, IllegalArgumentException, IllegalAccessException {
