@@ -20,66 +20,71 @@
  */
 package org.apache.qpid.jms.provider.amqp.message;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
+import static org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport.JMS_STREAM_MESSAGE;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.util.ArrayList;
 import java.util.List;
-import java.util.Map;
 
 import javax.jms.MessageEOFException;
 
 import org.apache.qpid.proton.amqp.Binary;
-import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.messaging.AmqpSequence;
 import org.apache.qpid.proton.amqp.messaging.AmqpValue;
 import org.apache.qpid.proton.amqp.messaging.Data;
 import org.apache.qpid.proton.amqp.messaging.MessageAnnotations;
 import org.apache.qpid.proton.amqp.messaging.Section;
 import org.apache.qpid.proton.message.Message;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase {
 
     @Test
-    public void testNewMessageToSendContainsMessageTypeAnnotation() throws Exception {
+    public void testNewMessageToSendReportsNoBody() throws Exception {
+        AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
+        assertFalse(amqpStreamMessageFacade.hasBody(), "Message should report no body");
+    }
+
+    @Test
+    public void testNewMessageToSendDoesnNotContainMessageTypeAnnotation() throws Exception {
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
 
-        Message protonMessage = amqpStreamMessageFacade.getAmqpMessage();
-        MessageAnnotations annotations = protonMessage.getMessageAnnotations();
-        Map<Symbol, Object> annotationsMap = annotations.getValue();
+        MessageAnnotations annotations = amqpStreamMessageFacade.getMessageAnnotations();
 
-        assertNotNull("MessageAnnotations section was not present", annotations);
-        assertNotNull("MessageAnnotations section value was not present", annotationsMap);
-
-        assertTrue("expected message type annotation to be present", annotationsMap.containsKey(AmqpMessageSupport.getSymbol(AmqpMessageSupport.JMS_MSG_TYPE)));
-        assertEquals("unexpected value for message type annotation value", AmqpMessageSupport.JMS_STREAM_MESSAGE, annotationsMap.get(AmqpMessageSupport.getSymbol(AmqpMessageSupport.JMS_MSG_TYPE)));
+        assertNull(annotations, "MessageAnnotations section was not present");
+        assertEquals(JMS_STREAM_MESSAGE, amqpStreamMessageFacade.getJmsMsgType());
     }
 
     @Test
     public void testNewMessageToSendContainsAmqpSequenceBody() throws Exception {
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
 
-        Message protonMessage = amqpStreamMessageFacade.getAmqpMessage();
-        Section body = protonMessage.getBody();
+        Section body = amqpStreamMessageFacade.getBody();
 
-        assertNotNull("Body section was not present", body);
-        assertTrue("Body section was not of expected type: " + body.getClass(), body instanceof AmqpSequence);
+        assertNotNull(body, "Body section was not present");
+        assertTrue(body instanceof AmqpSequence, "Body section was not of expected type: " + body.getClass());
     }
 
-    @Test(expected = MessageEOFException.class)
+    @Test
     public void testPeekWithNewMessageToSendThrowsMEOFE() throws Exception {
-        AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
-        amqpStreamMessageFacade.peek();
+        assertThrows(MessageEOFException.class, () -> {
+            AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
+            amqpStreamMessageFacade.peek();
+        });
     }
 
-    @Test(expected = MessageEOFException.class)
+    @Test
     public void testPopWithNewMessageToSendThrowsMEOFE() throws Exception {
-        AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
-        amqpStreamMessageFacade.pop();
+        assertThrows(MessageEOFException.class, () -> {
+            AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
+            amqpStreamMessageFacade.pop();
+        });
     }
 
     @Test
@@ -91,7 +96,7 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
     }
 
     @Test
@@ -103,7 +108,7 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
     }
 
     @Test
@@ -116,8 +121,9 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertTrue(amqpStreamMessageFacade.hasBody(), "Message should report that it contains a body");
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
     }
 
     @Test
@@ -130,9 +136,9 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
-        assertEquals("Unexpected value retrieved", Boolean.TRUE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.TRUE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
     }
 
     @Test
@@ -145,15 +151,15 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
 
         amqpStreamMessageFacade.reset();
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
 
-        assertEquals("Unexpected value retrieved", Boolean.TRUE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.TRUE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
     }
 
@@ -167,9 +173,9 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
-        assertEquals("Unexpected value retrieved", Boolean.TRUE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.TRUE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
 
         try {
@@ -181,26 +187,26 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         amqpStreamMessageFacade.reset();
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
-        assertEquals("Unexpected value retrieved", Boolean.TRUE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.TRUE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
     }
 
     @Test
     public void testHasNext() throws Exception {
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createNewStreamMessageFacade();
 
-        assertFalse("unexpected value", amqpStreamMessageFacade.hasNext());
+        assertFalse(amqpStreamMessageFacade.hasNext(), "unexpected value");
 
         // add some things
         amqpStreamMessageFacade.put(Boolean.TRUE);
         amqpStreamMessageFacade.put(Boolean.FALSE);
 
-        assertTrue("unexpected value", amqpStreamMessageFacade.hasNext());
+        assertTrue(amqpStreamMessageFacade.hasNext(), "unexpected value");
         amqpStreamMessageFacade.pop();
-        assertTrue("unexpected value", amqpStreamMessageFacade.hasNext());
+        assertTrue(amqpStreamMessageFacade.hasNext(), "unexpected value");
         amqpStreamMessageFacade.pop();
-        assertFalse("unexpected value", amqpStreamMessageFacade.hasNext());
+        assertFalse(amqpStreamMessageFacade.hasNext(), "unexpected value");
     }
 
     @Test
@@ -212,7 +218,7 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
         amqpStreamMessageFacade.put(Boolean.FALSE);
 
         // retrieve only some of it, leaving some unread
-        assertEquals("unexpected value", Boolean.TRUE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.TRUE, amqpStreamMessageFacade.peek(), "unexpected value");
         amqpStreamMessageFacade.pop();
 
         // clear
@@ -222,7 +228,7 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
         amqpStreamMessageFacade.put(Character.valueOf('c'));
 
         // check we can get it alone before another IOOBE (i.e position was reset, other contents cleared)
-        assertEquals("unexpected value", Character.valueOf('c'), amqpStreamMessageFacade.peek());
+        assertEquals(Character.valueOf('c'), amqpStreamMessageFacade.peek(), "unexpected value");
         amqpStreamMessageFacade.pop();
 
         try {
@@ -242,7 +248,7 @@ public class AmqpJmsStreamMessageFacadeTest extends AmqpJmsMessageTypesTestCase
 
         AmqpJmsStreamMessageFacade amqpStreamMessageFacade = createReceivedStreamMessageFacade(createMockAmqpConsumer(), message);
 
-        assertEquals("Unexpected value retrieved", Boolean.FALSE, amqpStreamMessageFacade.peek());
+        assertEquals(Boolean.FALSE, amqpStreamMessageFacade.peek(), "Unexpected value retrieved");
         amqpStreamMessageFacade.pop();
 
         try {
