@@ -16,7 +16,6 @@
  */
 package org.apache.qpid.jms.provider.mock;
 
-import java.io.IOException;
 import java.net.URI;
 import java.util.Collections;
 import java.util.List;
@@ -27,8 +26,6 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import javax.jms.JMSException;
-
 import org.apache.qpid.jms.message.JmsInboundMessageDispatch;
 import org.apache.qpid.jms.message.JmsMessageFactory;
 import org.apache.qpid.jms.message.JmsOutboundMessageDispatch;
@@ -40,11 +37,16 @@ import org.apache.qpid.jms.meta.JmsSessionId;
 import org.apache.qpid.jms.meta.JmsTransactionInfo;
 import org.apache.qpid.jms.provider.AsyncResult;
 import org.apache.qpid.jms.provider.Provider;
-import org.apache.qpid.jms.provider.ProviderClosedException;
 import org.apache.qpid.jms.provider.ProviderConstants.ACK_TYPE;
+import org.apache.qpid.jms.provider.ProviderException;
 import org.apache.qpid.jms.provider.ProviderFuture;
+import org.apache.qpid.jms.provider.ProviderFutureFactory;
 import org.apache.qpid.jms.provider.ProviderListener;
+import org.apache.qpid.jms.provider.ProviderSynchronization;
 import org.apache.qpid.jms.provider.amqp.AmqpProvider;
+import org.apache.qpid.jms.provider.exceptions.ProviderClosedException;
+import org.apache.qpid.jms.provider.exceptions.ProviderExceptionSupport;
+import org.apache.qpid.jms.provider.exceptions.ProviderIOException;
 import org.apache.qpid.jms.util.ThreadPoolUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -66,6 +68,7 @@ public class MockProvider implements Provider {
     private final ScheduledThreadPoolExecutor serializer;
     private final AtomicBoolean closed = new AtomicBoolean();
     private final MockRemotePeer context;
+    private final ProviderFutureFactory futureFactory;
 
     private long connectTimeout = JmsConnectionInfo.DEFAULT_CONNECT_TIMEOUT;
     private long closeTimeout = JmsConnectionInfo.DEFAULT_CLOSE_TIMEOUT;
@@ -73,11 +76,12 @@ public class MockProvider implements Provider {
     private MockProviderListener eventListener;
     private ProviderListener listener;
 
-    public MockProvider(URI remoteURI, MockProviderConfiguration configuration, MockRemotePeer context) {
+    public MockProvider(URI remoteURI, MockProviderConfiguration configuration, MockRemotePeer context, ProviderFutureFactory futureFactory) {
         this.remoteURI = remoteURI;
         this.configuration = configuration;
         this.context = context;
         this.stats = new MockProviderStats(context != null ? context.getContextStats() : null);
+        this.futureFactory = futureFactory;
 
         serializer = new ScheduledThreadPoolExecutor(1, new ThreadFactory() {
 
@@ -97,13 +101,13 @@ public class MockProvider implements Provider {
     }
 
     @Override
-    public void connect(JmsConnectionInfo connectionInfo) throws IOException {
+    public void connect(JmsConnectionInfo connectionInfo) throws ProviderException {
         checkClosed();
 
         stats.recordConnectAttempt();
 
         if (configuration.isFailOnConnect()) {
-            throw new IOException("Failed to connect to: " + remoteURI);
+            throw new ProviderIOException("Failed to connect to: " + remoteURI);
         }
 
         if (context != null) {
@@ -112,7 +116,7 @@ public class MockProvider implements Provider {
     }
 
     @Override
-    public void start() throws IOException, IllegalStateException {
+    public void start() throws ProviderException, IllegalStateException {
         checkClosed();
 
         if (listener == null) {
@@ -120,7 +124,7 @@ public class MockProvider implements Provider {
         }
 
         if (configuration.isFailOnStart()) {
-            throw new IOException();
+            throw new ProviderException("Error");
         }
     }
 
@@ -129,7 +133,7 @@ public class MockProvider implements Provider {
         if (closed.compareAndSet(false, true)) {
             stats.recordCloseAttempt();
 
-            final ProviderFuture request = new ProviderFuture();
+            final ProviderFuture request = futureFactory.createFuture();
             serializer.execute(new Runnable() {
 
                 @Override
@@ -141,13 +145,13 @@ public class MockProvider implements Provider {
                         }
 
                         if (configuration.isFailOnClose()) {
-                            request.onFailure(new RuntimeException());
+                            request.onFailure(new ProviderIOException("Failed on close"));
                         } else {
                             request.onSuccess();
                         }
-                    } catch (Exception e) {
+                    } catch (Throwable e) {
                         LOG.debug("Caught exception while closing the MockProvider");
-                        request.onFailure(e);
+                        request.onFailure(ProviderExceptionSupport.createOrPassthroughFatal(e));
                     }
                 }
             });
@@ -158,7 +162,7 @@ public class MockProvider implements Provider {
                 } else {
                     request.sync(closeTimeout, TimeUnit.MILLISECONDS);
                 }
-            } catch (IOException e) {
+            } catch (Exception e) {
                 LOG.warn("Error caught while closing Provider: ", e.getMessage());
             } finally {
                 ThreadPoolUtils.shutdownGraceful(serializer);
@@ -177,7 +181,7 @@ public class MockProvider implements Provider {
     }
 
     @Override
-    public void create(final JmsResource resource, final AsyncResult request) throws IOException, JMSException {
+    public void create(final JmsResource resource, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -198,15 +202,15 @@ public class MockProvider implements Provider {
                     }
 
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void start(final JmsResource resource, final AsyncResult request) throws IOException, JMSException {
+    public void start(final JmsResource resource, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -222,14 +226,14 @@ public class MockProvider implements Provider {
 
                     request.onSuccess();
                 } catch (Exception error) {
-                    request.onFailure(error);
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void stop(final JmsResource resource, final AsyncResult request) throws IOException, JMSException {
+    public void stop(final JmsResource resource, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -244,15 +248,15 @@ public class MockProvider implements Provider {
 
                     stats.recordStopResourceCall(resource);
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void destroy(final JmsResource resource, final AsyncResult request) throws IOException, JMSException {
+    public void destroy(final JmsResource resource, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -267,15 +271,15 @@ public class MockProvider implements Provider {
                     }
 
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void send(final JmsOutboundMessageDispatch envelope, final AsyncResult request) throws IOException, JMSException {
+    public void send(final JmsOutboundMessageDispatch envelope, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -302,15 +306,15 @@ public class MockProvider implements Provider {
                             }
                         }
                     }
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void acknowledge(final JmsSessionId sessionId, final ACK_TYPE ackType, final AsyncResult request) throws IOException, JMSException {
+    public void acknowledge(final JmsSessionId sessionId, final ACK_TYPE ackType, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -320,15 +324,15 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recoordSessionAcknowledgeCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void acknowledge(final JmsInboundMessageDispatch envelope, final ACK_TYPE ackType, final AsyncResult request) throws IOException, JMSException {
+    public void acknowledge(final JmsInboundMessageDispatch envelope, final ACK_TYPE ackType, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -338,15 +342,15 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recoordAcknowledgeCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void commit(final JmsTransactionInfo transactionInfo, final JmsTransactionInfo nextTransactionInfo, final AsyncResult request) throws IOException, JMSException {
+    public void commit(final JmsTransactionInfo transactionInfo, final JmsTransactionInfo nextTransactionInfo, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -356,15 +360,15 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recordCommitCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void rollback(final JmsTransactionInfo transactionInfo, final JmsTransactionInfo nextTransactionInfo, final AsyncResult request) throws IOException, JMSException {
+    public void rollback(final JmsTransactionInfo transactionInfo, final JmsTransactionInfo nextTransactionInfo, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -374,15 +378,15 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recordRollbackCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void recover(final JmsSessionId sessionId, final AsyncResult request) throws IOException {
+    public void recover(final JmsSessionId sessionId, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -392,15 +396,15 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recordRecoverCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void unsubscribe(final String subscription, final AsyncResult request) throws IOException, JMSException {
+    public void unsubscribe(final String subscription, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -410,15 +414,15 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recordUnsubscribeCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
     }
 
     @Override
-    public void pull(final JmsConsumerId consumerId, final long timeout, final AsyncResult request) throws IOException {
+    public void pull(final JmsConsumerId consumerId, final long timeout, final AsyncResult request) throws ProviderException {
         checkClosed();
         serializer.execute(new Runnable() {
 
@@ -428,8 +432,8 @@ public class MockProvider implements Provider {
                     checkClosed();
                     stats.recordPullCall();
                     request.onSuccess();
-                } catch (Exception error) {
-                    request.onFailure(error);
+                } catch (Throwable error) {
+                    request.onFailure(ProviderExceptionSupport.createNonFatalOrPassthrough(error));
                 }
             }
         });
@@ -443,7 +447,7 @@ public class MockProvider implements Provider {
             @Override
             public void run() {
                 if (!closed.get()) {
-                    listener.onConnectionFailure(new IOException("Connection lost"));
+                    listener.onConnectionFailure(new ProviderIOException("Connection lost"));
                 }
             }
         });
@@ -513,6 +517,16 @@ public class MockProvider implements Provider {
         this.connectTimeout = connectTimeout;
     }
 
+    @Override
+    public ProviderFuture newProviderFuture() {
+        return futureFactory.createFuture();
+    }
+
+    @Override
+    public ProviderFuture newProviderFuture(ProviderSynchronization synchronization) {
+        return futureFactory.createFuture(synchronization);
+    }
+
     //----- Implementation details -------------------------------------------//
 
     private void checkClosed() throws ProviderClosedException {
