@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -25,6 +25,8 @@ public class MockProviderConfiguration {
     private boolean failOnStart;
     private boolean failOnClose;
 
+    private boolean delayCompletionCalls;
+
     public boolean isFailOnConnect() {
         return failOnConnect;
     }
@@ -48,4 +50,12 @@ public class MockProviderConfiguration {
     public void setFailOnClose(boolean value) {
         this.failOnClose = value;
     }
+
+    public boolean isDelayCompletionCalls() {
+        return delayCompletionCalls;
+    }
+
+    public void setDelayCompletionCalls(boolean delayCompletionCalls) {
+        this.delayCompletionCalls = delayCompletionCalls;
+    }
 }
