@@ -16,9 +16,8 @@
  */
 package org.apache.qpid.jms.session;
 
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
-import java.io.IOException;
 import java.util.concurrent.TimeUnit;
 
 import javax.jms.ExceptionListener;
@@ -27,6 +26,7 @@ import javax.jms.Queue;
 import javax.jms.Session;
 
 import org.apache.qpid.jms.JmsConnection;
+import org.apache.qpid.jms.provider.ProviderException;
 import org.apache.qpid.jms.test.Wait;
 
 
@@ -45,18 +45,18 @@ public class JmsSessionFailedTest extends JmsSessionClosedTest {
             public void onException(JMSException exception) {
             }
         });
-        Queue destination = session.createQueue(_testName.getMethodName());
+        Queue destination = session.createQueue(_testMethodName);
 
         sender = session.createProducer(destination);
         receiver = session.createConsumer(destination);
         connection.start();
-        providerListener.onConnectionFailure(new IOException());
+        providerListener.onConnectionFailure(new ProviderException("Something went wrong"));
 
         final JmsConnection jmsConnection = connection;
         assertTrue(Wait.waitFor(new Wait.Condition() {
 
             @Override
-            public boolean isSatisified() throws Exception {
+            public boolean isSatisfied() throws Exception {
                 return !jmsConnection.isConnected();
             }
         }, TimeUnit.SECONDS.toMillis(30), TimeUnit.MILLISECONDS.toMillis(2)));
