@@ -16,18 +16,22 @@
  */
 package org.apache.qpid.jms.transports;
 
-import static org.junit.Assert.assertArrayEquals;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotEquals;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.fail;
+import static org.junit.jupiter.api.Assertions.assertArrayEquals;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNotEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.fail;
+
+import java.util.function.Supplier;
 
 import javax.net.ssl.SSLContext;
 
 import org.apache.qpid.jms.test.QpidJmsTestCase;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
 
+import io.netty.handler.proxy.ProxyHandler;
+
 /**
  * Test for class TransportOptions
  */
@@ -46,6 +50,7 @@ public class TransportOptionsTest extends QpidJmsTestCase {
     public static final int LOCAL_PORT = 30000;
     public static final boolean TEST_USE_EPOLL_VALUE = !TransportOptions.DEFAULT_USE_EPOLL;
     public static final boolean TEST_TRACE_BYTES_VALUE = !TransportOptions.DEFAULT_TRACE_BYTES;
+    public static final int TEST_SHARED_EVENT_LOOP_THREADS_VALUE = 5;
 
     private static final String PASSWORD = "password";
     private static final String CLIENT_KEYSTORE = "src/test/resources/client-jks.keystore";
@@ -64,13 +69,13 @@ public class TransportOptionsTest extends QpidJmsTestCase {
     private static final String[] DISABLED_CIPHERS = new String[] {"CIPHER_C"};
 
     private static final SSLContext SSL_CONTEXT = Mockito.mock(SSLContext.class);
+    private static final Supplier<ProxyHandler> PROXY_HANDLER_SUPPLIER = () -> Mockito.mock(ProxyHandler.class);
 
     private static final String JAVAX_NET_SSL_KEY_STORE = "javax.net.ssl.keyStore";
     private static final String JAVAX_NET_SSL_KEY_STORE_PASSWORD = "javax.net.ssl.keyStorePassword";
     private static final String JAVAX_NET_SSL_TRUST_STORE = "javax.net.ssl.trustStore";
     private static final String JAVAX_NET_SSL_TRUST_STORE_PASSWORD = "javax.net.ssl.trustStorePassword";
 
-
     @Test
     public void testCreate() {
         TransportOptions options = new TransportOptions();
@@ -93,6 +98,8 @@ public class TransportOptionsTest extends QpidJmsTestCase {
         assertNull(options.getTrustStorePassword());
         assertNull(options.getKeyAlias());
         assertNull(options.getSslContextOverride());
+        assertNull(options.getProxyHandlerSupplier());
+        assertEquals(TransportOptions.DEFAULT_SHARED_EVENT_LOOP_THREADS, options.getSharedEventLoopThreads());
     }
 
     @Test
@@ -139,10 +146,12 @@ public class TransportOptionsTest extends QpidJmsTestCase {
         assertEquals(LOCAL_ADDRESS,options.getLocalAddress());
         assertEquals(LOCAL_PORT,options.getLocalPort());
         assertEquals(SSL_CONTEXT, options.getSslContextOverride());
+        assertEquals(PROXY_HANDLER_SUPPLIER, options.getProxyHandlerSupplier());
         assertArrayEquals(ENABLED_PROTOCOLS,options.getEnabledProtocols());
         assertArrayEquals(DISABLED_PROTOCOLS,options.getDisabledProtocols());
         assertArrayEquals(ENABLED_CIPHERS,options.getEnabledCipherSuites());
         assertArrayEquals(DISABLED_CIPHERS,options.getDisabledCipherSuites());
+        assertEquals(TEST_SHARED_EVENT_LOOP_THREADS_VALUE, options.getSharedEventLoopThreads());
     }
 
     @Test
@@ -220,6 +229,7 @@ public class TransportOptionsTest extends QpidJmsTestCase {
         assertEquals(KEY_ALIAS, options.getKeyAlias());
         assertEquals(CONTEXT_PROTOCOL, options.getContextProtocol());
         assertEquals(SSL_CONTEXT, options.getSslContextOverride());
+        assertEquals(PROXY_HANDLER_SUPPLIER, options.getProxyHandlerSupplier());
         assertArrayEquals(ENABLED_PROTOCOLS,options.getEnabledProtocols());
         assertArrayEquals(DISABLED_PROTOCOLS,options.getDisabledProtocols());
         assertArrayEquals(ENABLED_CIPHERS,options.getEnabledCipherSuites());
@@ -253,6 +263,7 @@ public class TransportOptionsTest extends QpidJmsTestCase {
         options.setConnectTimeout(TEST_CONNECT_TIMEOUT);
         options.setDefaultSslPort(TEST_DEFAULT_SSL_PORT);
         options.setSslContextOverride(SSL_CONTEXT);
+        options.setProxyHandlerSupplier(PROXY_HANDLER_SUPPLIER);
 
         return options;
     }
@@ -328,6 +339,8 @@ public class TransportOptionsTest extends QpidJmsTestCase {
         options.setDisabledCipherSuites(DISABLED_CIPHERS);
         options.setLocalAddress(LOCAL_ADDRESS);
         options.setLocalPort(LOCAL_PORT);
+        options.setProxyHandlerSupplier(PROXY_HANDLER_SUPPLIER);
+        options.setSharedEventLoopThreads(TEST_SHARED_EVENT_LOOP_THREADS_VALUE);
 
         return options;
     }
