@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -16,12 +16,13 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import java.util.Enumeration;
+import java.util.concurrent.TimeUnit;
 
 import javax.jms.Message;
 import javax.jms.MessageConsumer;
@@ -33,8 +34,10 @@ import javax.jms.TextMessage;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.JmsConnection;
+import org.apache.qpid.jms.policy.JmsDefaultPrefetchPolicy;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.Timeout;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -46,7 +49,8 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
 
     protected static final Logger LOG = LoggerFactory.getLogger(JmsQueueBrowserTest.class);
 
-    @Test(timeout = 60000)
+    @Test
+    @Timeout(40)
     public void testCreateQueueBrowser() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -63,7 +67,8 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         assertEquals(0, proxy.getQueueSize());
     }
 
-    @Test(timeout = 60000)
+    @Test
+    @Timeout(40)
     public void testNoMessagesBrowserHasNoElements() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -83,7 +88,8 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         assertFalse(enumeration.hasMoreElements());
     }
 
-    @Test(timeout=30000)
+    @Test
+    @Timeout(30)
     public void testBroseOneInQueue() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -99,6 +105,7 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         while (enumeration.hasMoreElements()) {
             Message m = (Message) enumeration.nextElement();
             assertTrue(m instanceof TextMessage);
+            LOG.debug("Browsed message {} from Queue {}", m, queue);
         }
 
         browser.close();
@@ -109,7 +116,8 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         assertTrue(msg instanceof TextMessage);
     }
 
-    @Test(timeout = 60000)
+    @Test
+    @Timeout(40)
     public void testBrowseAllInQueue() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -122,6 +130,39 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         QueueViewMBean proxy = getProxyToQueue(getDestinationName());
         assertEquals(5, proxy.getQueueSize());
 
+        QueueBrowser browser = session.createBrowser(queue);
+        assertNotNull(browser);
+        Enumeration enumeration = browser.getEnumeration();
+        int count = 0;
+        while (enumeration.hasMoreElements()) {
+            Message msg = (Message) enumeration.nextElement();
+            assertNotNull(msg);
+            LOG.debug("Recv: {}", msg);
+            count++;
+            TimeUnit.MILLISECONDS.sleep(50);
+        }
+        assertFalse(enumeration.hasMoreElements());
+        assertEquals(5, count);
+    }
+
+    @Test
+    @Timeout(40)
+    public void testBrowseAllInQueuePrefetchOne() throws Exception {
+        connection = createAmqpConnection();
+
+        JmsConnection jmsConnection = (JmsConnection) connection;
+        ((JmsDefaultPrefetchPolicy) jmsConnection.getPrefetchPolicy()).setQueueBrowserPrefetch(1);
+
+        connection.start();
+
+        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+        assertNotNull(session);
+        Queue queue = session.createQueue(getDestinationName());
+        sendToAmqQueue(5);
+
+        QueueViewMBean proxy = getProxyToQueue(getDestinationName());
+        assertEquals(5, proxy.getQueueSize());
+
         QueueBrowser browser = session.createBrowser(queue);
         assertNotNull(browser);
         Enumeration enumeration = browser.getEnumeration();
@@ -136,7 +177,40 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         assertEquals(5, count);
     }
 
-    @Test(timeout = 60000)
+    @Test
+    @Timeout(40)
+    public void testBrowseAllInQueueZeroPrefetch() throws Exception {
+        connection = createAmqpConnection();
+
+        JmsConnection jmsConnection = (JmsConnection) connection;
+        ((JmsDefaultPrefetchPolicy) jmsConnection.getPrefetchPolicy()).setQueueBrowserPrefetch(0);
+
+        connection.start();
+
+        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+        assertNotNull(session);
+        Queue queue = session.createQueue(getDestinationName());
+        sendToAmqQueue(5);
+
+        QueueViewMBean proxy = getProxyToQueue(getDestinationName());
+        assertEquals(5, proxy.getQueueSize());
+
+        QueueBrowser browser = session.createBrowser(queue);
+        assertNotNull(browser);
+        Enumeration enumeration = browser.getEnumeration();
+        int count = 0;
+        while (enumeration.hasMoreElements()) {
+            Message msg = (Message) enumeration.nextElement();
+            assertNotNull(msg);
+            LOG.debug("Recv: {}", msg);
+            count++;
+        }
+        assertFalse(enumeration.hasMoreElements());
+        assertEquals(5, count);
+    }
+
+    @Test
+    @Timeout(40)
     public void testBrowseAllInQueueTxSession() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -163,7 +237,8 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         assertEquals(5, count);
     }
 
-    @Test(timeout = 60000)
+    @Test
+    @Timeout(40)
     public void testQueueBrowserInTxSessionLeavesOtherWorkUnaffected() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -206,10 +281,11 @@ public class JmsQueueBrowserTest extends AmqpTestSupport {
         assertEquals(10, proxy.getQueueSize());
     }
 
-    @Test(timeout = 90000)
+    @Test
+    @Timeout(60)
     public void testBrowseAllInQueueSmallPrefetch() throws Exception {
         connection = createAmqpConnection();
-        ((JmsConnection) connection).getPrefetchPolicy().setQueueBrowserPrefetch(10);
+        ((JmsDefaultPrefetchPolicy) ((JmsConnection) connection).getPrefetchPolicy()).setQueueBrowserPrefetch(1);
         connection.start();
 
         final int MSG_COUNT = 30;
